jQuery(document).ready(function($) {
    /**
     * File customizer.js.
     *
     * Theme Customizer enhancements for a better user experience.
     *
     * Contains handlers to make Theme Customizer preview reload changes asynchronously.
     */

    function chankhe_set_dynamic_css(control, style) {
        jQuery('style.' + control).remove();
        jQuery('head').append('<style class="' + control + '">' + style + '</style>');
    }

    $('.cl-repeater-field-title.accordion-section-title').click(function() {
        $(this).toggleClass('expanded');
    });

    $('.cl-repeater-selected-icon').click(function() {
        $(this).find(".fa-angle-down").toggleClass('fa-angle-up');
    });

    // Site title and description.
    wp.customize('blogname', function(value) {
        value.bind(function(to) {
            $('.site-title a').text(to);
        });
    });

    wp.customize('blogdescription', function(value) {
        value.bind(function(to) {
            $('.site-description').text(to);
        });
    });

    // Header text color.
    wp.customize('header_textcolor', function(value) {
        value.bind(function(to) {
            if ('blank' === to) {
                $('.site-title, .site-description').css({
                    'clip': 'rect(1px, 1px, 1px, 1px)',
                    'position': 'absolute'
                });
            } else {
                $('.site-title, .site-description').css({
                    'clip': 'auto',
                    'position': 'relative'
                });
                $('.site-title a, .site-description').css({
                    'color': to
                });
            }
        });
    });


    // create custom associative array
    var section_selector = {
        'chankhe_promoservice': '#chankhefeature',
        'chankhe_aboutus': '#about_us_front',
        'chankhe_video_calltoaction': '#calltoactionvideo_promo_wrapper',
        'chankhe_service': '#chankheservices',
        'chankhe_counter': '#chankhecounter_wrap',
        'chankhe_blog': '#chankheblog',
        'chankhe_team': '#chankheteam',
        'chankhe_testimonial': '#chankhetestimonial'
    };


    $.each(section_selector, function(section, selector) {
        wp.customize(section + '_bg_type', function(value) {
            value.bind(function onChange(to) {

                if (to === 'default') {
                    $(selector).css('background-image', 'none');
                    $(selector).css('background-color', 'inherit');
                }

                if (to === 'color-bg') {
                    var color = wp.customize(section + '_bg_color').get();
                    $(selector).css('background-image', 'none');
                    $(selector).css('background-color', color);
                }

                if (to === 'gradient-bg') {
                    var gradient = wp.customize(section + '_bg_gradient').get();
                    var css = selector + '{' + gradient + '}';
                    $(selector).css('background-image', '');
                    $(selector).css('background-color', 'transparent');
                    chankhe_set_dynamic_css(section + '_bg_gradient', css);
                }

                if (to === 'image-bg') {
                    var image = wp.customize(section + '_background_image').get();
                    var image_repeat = wp.customize(section + '_background_image_repeat').get();
                    var image_size = wp.customize(section + '_background_image_size').get();
                    var image_position = wp.customize(section + '_background_image_position').get();
                    var image_attach = wp.customize(section + '_background_image_attach').get();
                    $(selector).css({ 'background-image': 'url(' + image + ')', 'background-repeat': image_repeat, 'background-size': image_size, 'background-position': image_position, 'background-attachment': image_attach });
                }

                if (to === 'default' || to === 'color-bg' || to === 'gradient-bg' || to === 'image-bg') {
                    $(selector + ' iframe').css('display', 'none');
                }

            });
        });

        wp.customize(section + '_bg_color', function(value) {
            value.bind(function(to) {
                $(selector).css('background-color', to);
            });
        });

        wp.customize(section + '_text_color', function(value) {
            value.bind(function(to) {
                var css = selector + ' *:not(.default-color, .primary-color){color:' + to + '}';
                chankhe_set_dynamic_css(section + '_bg_gradient', css);
            });
        });

        wp.customize(section + '_bg_gradient', function(value) {
            value.bind(function(to) {
                var css = selector + '{' + to + '}';
                chankhe_set_dynamic_css(section + '_bg_gradient', css);
            });
        });

        wp.customize(section + '_background_image', function(value) {
            value.bind(function(to) {
                $(selector).css('background-image', 'url(' + to + ')');
            });
        });

        wp.customize(section + '_background_image_repeat', function(value) {
            value.bind(function(to) {
                $(selector).css('background-repeat', to);
            });
        });

        wp.customize(section + '_background_image_size', function(value) {
            value.bind(function(to) {
                $(selector).css('background-size', to);
            });
        });

        wp.customize(section + '_background_image_position', function(value) {
            value.bind(function(to) {
                $(selector).css('background-position', to);
            });
        });

        wp.customize(section + '_background_image_attach', function(value) {
            value.bind(function(to) {
                $(selector).css('background-attachment', to);
            });
        });

        wp.customize(section + '_alignment', function(value) {
            value.bind(function(to) {
                var align = JSON.parse(to);
                var remove_css = 'text-left text-center text-right tablet-text-left tablet-text-center tablet-text-right mobile-text-left mobile-text-center mobile-text-right';
                var apply_css = '';
                if ((align.desktop != '') && (align.desktop !== undefined)) apply_css = apply_css + align.desktop;
                if ((align.tablet != '') && (align.tablet !== undefined)) apply_css = apply_css + ' tablet-' + align.tablet;
                if ((align.mobile != '') && (align.mobile !== undefined)) apply_css = apply_css + ' mobile-' + align.mobile;
                $(selector).removeClass(remove_css).addClass(apply_css);
            });
        });

        wp.customize(section + '_margin', function(value) {
            value.bind(function(to) {

                var section_margin = JSON.parse(to);
                $(selector).css({ "margin-top": section_margin.desktop.top + "px", "margin-right": section_margin.desktop.right + "px", "margin-bottom": section_margin.desktop.bottom + "px", "margin-left": section_margin.desktop.left + "px" });

                if (($(window).width() >= 700) && ($(window).width() < 992)) {
                    $(selector).css({ "margin-top": section_margin.tablet.top + "px", "margin-right": section_margin.tablet.right + "px", "margin-bottom": section_margin.tablet.bottom + "px", "margin-left": section_margin.tablet.left + "px" });
                }

                if ($(window).width() < 500) {
                    $(selector).css({ "margin-top": section_margin.mobile.top + "px", "margin-right": section_margin.mobile.right + "px", "margin-bottom": section_margin.mobile.bottom + "px", "margin-left": section_margin.mobile.left + "px" });
                }

            });
        });

        wp.customize(section + '_padding', function(value) {
            value.bind(function(to) {

                var section_padding = JSON.parse(to);
                $(selector).css({ "padding-top": section_padding.desktop.top + "px", "padding-right": section_padding.desktop.right + "px", "padding-bottom": section_padding.desktop.bottom + "px", "padding-left": section_padding.desktop.left + "px" });

                if (($(window).width() >= 700) && ($(window).width() < 992)) {
                    $(selector).css({ "padding-top": section_padding.tablet.top + "px", "padding-right": section_padding.tablet.right + "px", "padding-bottom": section_padding.tablet.bottom + "px", "padding-left": section_padding.tablet.left + "px" });
                }

                if ($(window).width() < 500) {
                    $(selector).css({ "padding-top": section_padding.mobile.top + "px", "padding-right": section_padding.mobile.right + "px", "padding-bottom": section_padding.mobile.bottom + "px", "padding-left": section_padding.mobile.left + "px" });
                }

            });
        });


    });

});