<?php
/**
 * Chankhe Theme Customizer Setting Panel
 *
 * @package Chankhe
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function chankhe_customize_register( $wp_customize ) {

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {

		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'chankhe_customize_partial_blogname',
		) );

		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'chankhe_customize_partial_blogdescription',
		) );
	}


	/**
	 *	Enable Front Page.
	*/
    $wp_customize->add_setting('chankhe_enable_frontpage', array(
    	'default' => 'disable',
        'sanitize_callback' => 'chankhe_sanitize_switch',	
    ));

	$wp_customize->add_control(new Chankhe_Switch_Control($wp_customize, 'chankhe_enable_frontpage', array(
		'label' => esc_html__('Enable Front Page', 'chankhe'),
		'section' => 'static_front_page',
		'priority' => -1,
		'description' => esc_html__( 'Note :- Front Page only Works after selecting "Your latest posts" Options & Enabling the check box', 'chankhe' ),
		'switch_label' => array(
			'enable' => esc_html__('Yes', 'chankhe'),
			'disable' => esc_html__('No', 'chankhe'),
		),
	)));

    /**
	 * Add General Settings Panel
	 *
	 * @since 1.0.0
	*/
	$wp_customize->add_panel(
	    'chankhe_general_settings_panel',
	    array(
	        'priority'       => 30,
	        'title'          => esc_html__( 'Header Options', 'chankhe' ),
	    )
	);

		$wp_customize->get_section( 'title_tagline' )->panel = 'chankhe_general_settings_panel';
		$wp_customize->get_section( 'title_tagline' )->priority = 2;

		/**
		 *	Navigation
		*/
		$wp_customize->add_section('chankhe_navigation_section', array(
			'title'		=>	esc_html__('Header Style','chankhe'),
			'panel'		=> 'chankhe_general_settings_panel',
			'priority'  => 2
		));

			$wp_customize->add_setting('chankhe_navbar_transparent', array(
				'default' => true,
				'sanitize_callback' => 'chankhe_sanitize_checkbox',
			));

			$wp_customize->add_control('chankhe_navbar_transparent', array(
				'type' => 'checkbox',
				'label' => esc_html__('Transparent Navbar', 'chankhe'),
				'section' => 'chankhe_navigation_section',
			));
			
			$wp_customize->add_setting('chankhe_navbar_layout', array(
				//'transport' => 'postMessage',
				'sanitize_callback' => 'sanitize_text_field',
				'default' => 'nav-1'
			));
			$wp_customize->add_control(new Chankhe_Image_Select($wp_customize, 'chankhe_navbar_layout', array(
				'section' => 'chankhe_navigation_section',
				'label' => esc_html__('Header Layout', 'chankhe'),
				'image_path' => get_template_directory_uri() . '/assets/images/customizer/nav/',
				'choices' => array(
					'nav-1' => esc_html__('Layout 1', 'chankhe'),
					'nav-2' => esc_html__ ('Layout 2', 'chankhe'),
				)
			)));
			

		/**
		 * Tab Section
		 */
		$wp_customize->add_setting('chankhe_header_settings_nav', array(
			'sanitize_callback' => 'wp_kses_post',
		));
		$wp_customize->add_control(new Chankhe_Custom_Control_Tab($wp_customize, 'chankhe_header_settings_nav', array(
			'type' => 'tab',
			'priority' => 1,
			'section' => 'header_image',
			'buttons' => array(
				array(
					'name' => esc_html__('Content', 'chankhe'),
					'icon'  => 'admin-tools',
					'fields' => array(
						'chankhe_header_image_sitewide',
						'header_image',
						
					),
					'active' => true,
				),
				array(
					'name' => esc_html__('Style', 'chankhe'),
					'icon'  => 'buddicons-community',
					'fields' => array(
						'chankhe_header_layout',
						'chankhe_header_gradient_color'
					),
				)
			),
		)));

		$wp_customize->get_section( 'header_image' )->panel = 'chankhe_general_settings_panel';
		$wp_customize->get_section( 'header_image' )->title = esc_html__('Breadcrumb Settings', 'chankhe');
		$wp_customize->get_section( 'header_image' )->priority = 20;

		
		// Header Gradient Color
		$wp_customize->add_setting('chankhe_header_gradient_color', array(
		    'default' => '#165da5',
		    'sanitize_callback' => 'sanitize_text_field',
		));

		$wp_customize->add_control(new Chankhe_Gradient_Control($wp_customize, "chankhe_header_gradient_color", array(
			'section' => 'header_image',
			'label' => esc_html__('Header Gradient Color', 'chankhe'),
		)));

		$wp_customize->add_setting('chankhe_header_layout', array(
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
			'default' => 'layout-1'
		));
		$wp_customize->add_control(new Chankhe_Image_Select($wp_customize, 'chankhe_header_layout', array(
			'section' => 'header_image',
			'label' => esc_html__('Layout', 'chankhe'),
			'image_path' => get_template_directory_uri() . '/assets/images/customizer/header/',
			'choices' => array(
				'layout-1' => esc_html__('Layout 1', 'chankhe'),
				'layout-2' => esc_html__('Layout 2', 'chankhe'),
				// 'layout-3' => esc_html__('Layout 3', 'chankhe'),
			)
		)));
		
		// Enable or Disable Breadcrumb.
		$wp_customize->add_setting('chankhe_enable_breadcrumbs', array(
			'default' => 'enable',
			'sanitize_callback' => 'chankhe_sanitize_switch',     //done
		));

		$wp_customize->add_control(new Chankhe_Switch_Control($wp_customize, 'chankhe_enable_breadcrumbs', array(
			'label' => esc_html__('Enable Breadcrumbs', 'chankhe'),
			'section' => 'header_image',
			'switch_label' => array(
				'enable' => esc_html__('Yes', 'chankhe'),
				'disable' => esc_html__('No', 'chankhe'),
			),
		)));


		$wp_customize->get_section( 'colors' )->title = esc_html__('Colors Setting', 'chankhe');
		$wp_customize->get_section( 'colors' )->priority = 8;

		// Primary Color.
		$wp_customize->add_setting('chankhe_primary_color', array(
		    'default' => '#165da5',
		    'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control('chankhe_primary_color', array(
		    'type' => 'color',
		    'label' => esc_html__('Primary Color', 'chankhe'),
		    'section' => 'colors',
		    'priority' => 1,
		));

		$wp_customize->get_section( 'background_image' )->panel = 'chankhe_theme_options';
		$wp_customize->get_section( 'background_image' )->priority = 65;
		$wp_customize->get_section( 'static_front_page' )->priority = 1;


    // List All Pages
	$pages = array();

	$pages_obj = get_pages();

	$pages[''] = esc_html__('Select Page', 'chankhe');

	foreach ($pages_obj as $page) {
	    $pages[$page->ID] = $page->post_title;
	}

	// List All Category
	$categories = get_categories();
	$blog_cat = array();

	foreach ($categories as $category) {
	    $blog_cat[$category->term_id] = $category->name;
	}


	/**
	 * Home Page Settings
	*/
	$wp_customize->add_panel('chankhe_frontpage_settings', array(
		'title'		=>	esc_html__('Home Sections','chankhe'),
		'priority'	=>	35,
		'description' => esc_html__('Drag and Drop to Reorder', 'chankhe'). '<img class="chankhe-drag-spinner" src="'.admin_url('/images/spinner.gif').'">',
	));


		/**
		 *	Main Banner Slider.
		*/
		$wp_customize->add_section('chankhe_slider_section', array(
			'title'		=>	esc_html__('Home Slider Settings','chankhe'),
			'panel'		=> 'chankhe_frontpage_settings',
			'priority'  => -1
		));

		/**
		 * Tab Section
		 */
		$wp_customize->add_setting('chankhe_slider_nav', array(
			'sanitize_callback' => 'wp_kses_post',
		));
		$wp_customize->add_control(new Chankhe_Custom_Control_Tab($wp_customize, 'chankhe_slider_nav', array(
			'type' => 'tab',
			'section' => 'chankhe_slider_section',
			'buttons' => array(
				array(
					'name' => esc_html__('Content', 'chankhe'),
					'fields' => array(
						'chankhe_slider_type',
						'chankhe_banner_bg_image',
						'chankhe_slider_video_url',
						'chankhe_banner_title',
						'chankhe_banner_description',
						'chankhe_banner_btn_text',
						'chankhe_banner_btn_url'
					),
					'active' => true,
				),
				array(
					'name' => esc_html__('Style', 'chankhe'),
					'fields' => array(
						
					),
				)
			),
		)));

		$wp_customize->selective_refresh->add_partial( 'chankhe_banner_title', array(
			'settings' => array( 'chankhe_banner_title' ),
			'selector' => "#banner-slider",
			'container_inclusive' => true
		));


		/**
		 * Advnace and Default
		 */
		$wp_customize->add_setting( 'chankhe_slider_type', array(
			// 'transport'         => 'postMessage',
			'default'           => 'default',
			'sanitize_callback' => 'sanitize_text_field'
		));

		$wp_customize->add_control('chankhe_slider_type', array(
			'label'		  => esc_html__( 'Type', 'chankhe' ),
			'section'	  => 'chankhe_slider_section',
			'type' 		  => 'select',
			'choices'	  => array(
				'default' => esc_html__( 'Default', 'chankhe' ),
				'video' => esc_html__( 'Video', 'chankhe' ),
			)
		));
		
	

		// Registers example_background settings
		$wp_customize->add_setting("chankhe_banner_background_image", array(
			'sanitize_callback' => 'esc_url_raw',
			// 'transport' => 'postMessage'
		));
		$wp_customize->add_setting("chankhe_banner_background_image_id", array(
			'sanitize_callback' => 'absint',
			// 'transport' => 'postMessage'
		));
		$wp_customize->add_setting("chankhe_banner_background_image_repeat", array(
			'default' => 'no-repeat',
			'sanitize_callback' => 'sanitize_text_field',
			// 'transport' => 'postMessage'
		));
		$wp_customize->add_setting("chankhe_banner_background_image_size", array(
			'default' => 'cover',
			'sanitize_callback' => 'sanitize_text_field',
			// 'transport' => 'postMessage'
		));
		$wp_customize->add_setting("chankhe_banner_background_image_position", array(
			'default' => 'center center',
			'sanitize_callback' => 'sanitize_text_field',
			// 'transport' => 'postMessage'
		));
		$wp_customize->add_setting("chankhe_banner_background_image_attach", array(
			'default' => 'fixed',
			'sanitize_callback' => 'sanitize_text_field',
			// 'transport' => 'postMessage'
		));
		// Registers control
		$wp_customize->add_control(new Chankhe_Background_Control($wp_customize, "chankhe_banner_bg_image", array(
			'label' => esc_html__('Background Image', 'chankhe'),
			'section' => 'chankhe_slider_section',
			'settings' => array(
				'image_url' => "chankhe_banner_background_image",
				'image_id' => "chankhe_banner_background_image_id",
				'repeat' => "chankhe_banner_background_image_repeat", // Use false to hide the field
				'size' => "chankhe_banner_background_image_size",
				'position' => "chankhe_banner_background_image_position",
				'attach' => "chankhe_banner_background_image_attach"
			),
		)));
		
		/**
		 * Video Banner Content
		 */
		$wp_customize->add_setting( 'chankhe_slider_video_url', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => 'xf86EzuLXu0',
			// 'transport' => 'postMessage'			
		) );

		$wp_customize->add_control( 'chankhe_slider_video_url', array(
			'label' => esc_html__('Youtube Video ID', 'chankhe'),
			'description' => esc_html__('https://www.youtube.com/watch?v=xf86EzuLXu0. Add only xf86EzuLXu0', 'chankhe'),
			'section'  => 'chankhe_slider_section',
			'type'     => 'text',
		));
		$wp_customize->add_setting( 'chankhe_banner_title', array(
			'sanitize_callback' => 'wp_kses_post',
			// 'transport' => 'postMessage'			
		) );

		$wp_customize->add_control( 'chankhe_banner_title', array(
			'label'    => esc_html__( 'Banner Title', 'chankhe' ),
			'section'  => 'chankhe_slider_section',
			'type'     => 'text',
		));

		$wp_customize->add_setting( 'chankhe_banner_description', array(
			'sanitize_callback' => 'wp_kses_post',
			// 'transport' => 'postMessage'			
		) );

		$wp_customize->add_control( 'chankhe_banner_description', array(
			'label'    => esc_html__( 'Description', 'chankhe' ),
			'section'  => 'chankhe_slider_section',
			'type'     => 'textarea',
		));
		
		$wp_customize->add_setting( 'chankhe_banner_btn_url', array(
			'sanitize_callback' => 'sanitize_text_field',
			// 'transport' => 'postMessage'			
		) );

		$wp_customize->add_control( 'chankhe_banner_btn_url', array(
			'label'    => esc_html__( 'Button Link', 'chankhe' ),
			'section'  => 'chankhe_slider_section',
			'type'     => 'text',
		));
		


	/**
	 * Features Service Section 
	*/
	$wp_customize->add_section('chankhe_promoservice_section', array(
		'title'		=>	esc_html__('Features Service Section','chankhe'),
		'panel'		=> 'chankhe_frontpage_settings',
		'priority'  => chankhe_get_section_position('chankhe_promoservice_section')
	));


		/**
         * Enable/Disable Option
         *
         * @since 1.0.0
        */
        $wp_customize->add_setting('chankhe_features_service_section', array(
		    'default' => 'enable',
			'transport' => 'postMessage',
		    'sanitize_callback' => 'chankhe_sanitize_switch',     //done
		));

		$wp_customize->add_control(new Chankhe_Switch_Control($wp_customize, 'chankhe_features_service_section', array(
		    'label' => esc_html__('Enable / Disable', 'chankhe'),
			'priority' => 1,
		    'section' => 'chankhe_promoservice_section',
		    'switch_label' => array(
		        'enable' => esc_html__('Yes', 'chankhe'),
		        'disable' => esc_html__('No', 'chankhe'),
		    ),
		)));

		$wp_customize->selective_refresh->add_partial( 'chankhe_features_service_section', array(
			'settings' => array( 'chankhe_features_service_section' ),
			'selector' => "#chankheservices",
			'container_inclusive' => true,
			'render_callback' => function() {
				return get_template_part( 'section/section', 'service' );
			},
		));


		$wp_customize->add_setting('chankhe_promo_service_nav', array(
			'sanitize_callback' => 'wp_kses_post',
		));
		$wp_customize->add_control(new Chankhe_Custom_Control_Tab($wp_customize, 'chankhe_promo_service_nav', array(
			'type' => 'tab',
			'priority' => 1,
			'section' => 'chankhe_promoservice_section',
			'buttons' => array(
				array(
					'name' => esc_html__('Content', 'chankhe'),
					'icon' => 'welcome-widgets-menus',
					'fields' => array(
						'chankhe_promo_service',
						'chankhe_banner_bg_image',
						'chankhe_slider_video_url',
						'chankhe_banner_title',
						'chankhe_banner_description',
						'chankhe_banner_btn_text',
						'chankhe_banner_btn_url'
					),
					'active' => true,
				),
				array(
					'name' => esc_html__('Style', 'chankhe'),
					'icon' => 'admin-customizer',
					'fields' => array(
						'chankhe_promoservice_bg_type',
						'chankhe_promoservice_bg_color',
						'chankhe_promoservice_bg_gradient',
						'chankhe_promoservice_bg_image',
						'chankhe_promoservice_bg_video',
						'chankhe_promoservice_text_color',
					),
				),
				array(
					'name' => esc_html__( 'Advance', 'chankhe'),
					'icon' => 'admin-settings',
					'fields' => array(
						'chankhe_promoservice_margin_msg',
						'chankhe_promoservice_margin',
						'chankhe_promoservice_padding',
						'chankhe_promoservice_alignment',
					)
				),
			),
		)));  


		//  Features Service Page.
		$wp_customize->add_setting('chankhe_promo_service', array(
			'transport' => 'postMessage',
		    'sanitize_callback' => 'chankhe_sanitize_repeater',		//done
		    'default' => json_encode(array(
		        array(
		            'promoservice_page' => '',
		            'promoservice_icon' =>'fa fa-cogs',

		        )
		    ))
		));

		$wp_customize->add_control(new Chankhe_Repeater_Control( $wp_customize, 
			'chankhe_promo_service', 

			array(
			    'label' 	   => esc_html__('Features Service Settings', 'chankhe'),
			    'section' 	   => 'chankhe_promoservice_section',
			    'settings' 	   => 'chankhe_promo_service',
			    'box_label' => esc_html__('Features Service Settings', 'chankhe'),
			    'add_label' => esc_html__('Add New Page', 'chankhe'),
			),

		    array(

		        'promoservice_page' => array(
		            'type' => 'select',
		            'label' => esc_html__('Features Service Page', 'chankhe'),
		            'options' => $pages
		        ),

		        'promoservice_icon' => array(
		            'type' => 'icon',
		            'label' => esc_html__('Choose Icon', 'chankhe'),
		            'default' => 'fa fa-cogs'
		        )
			)
		));

		$wp_customize->selective_refresh->add_partial( 'chankhe_promo_service', array(
			'settings' => array( 'chankhe_promo_service' ),
			'selector' => "#chankhefeature",
			'container_inclusive' => true,
			'render_callback' => function() {
				return get_template_part( 'section/section', 'service' );
			},
		));


	/**
	 * About Us Section 
	*/
	$wp_customize->add_section('chankhe_aboutus_section', array(
		'title'		=>	esc_html__('About Us Section','chankhe'),
		'panel'		=> 'chankhe_frontpage_settings',
		'priority'  => chankhe_get_section_position('chankhe_aboutus_section')
	));

		/**
         * Enable/Disable Option
         *
         * @since 1.0.0
        */
        $wp_customize->add_setting('chankhe_aboutus_service_section', array(
		    'default' => 'enable',
			'transport' => 'postMessage',
		    'sanitize_callback' => 'chankhe_sanitize_switch',     //done
		));

		$wp_customize->add_control(new Chankhe_Switch_Control($wp_customize, 'chankhe_aboutus_service_section', array(
		    'label' => esc_html__('Enable / Disable', 'chankhe'),
		    'section' => 'chankhe_aboutus_section',
			'priority' => 1,
		    'switch_label' => array(
		        'enable' => esc_html__('Yes', 'chankhe'),
		        'disable' => esc_html__('No', 'chankhe'),
		    ),
		)));

		$wp_customize->selective_refresh->add_partial( 'chankhe_aboutus_service_section', array(
			'settings' => array( 'chankhe_aboutus_service_section' ),
			'selector' => "#about_us_front",
			'container_inclusive' => true,
			'render_callback' => function() {
				return get_template_part( 'section/section', 'aboutus' );
			},
		));

		$wp_customize->add_setting('chankhe_aboutus_service_nav', array(
			'sanitize_callback' => 'wp_kses_post',
		));
		$wp_customize->add_control(new Chankhe_Custom_Control_Tab($wp_customize, 'chankhe_aboutus_service_nav', array(
			'type' => 'tab',
			'priority' => 1,
			'section' => 'chankhe_aboutus_section',
			'buttons' => array(
				array(
					'name' => esc_html__('Content', 'chankhe'),
					'icon' => 'welcome-widgets-menus',
					'fields' => array(
						'chankhe_aboutus_top_title',
						'chankhe_aboutus',
						'chankhe_aboutus_image',
					),
					'active' => true,
				),
				array(
					'name' => esc_html__('Style', 'chankhe'),
					'icon' => 'admin-customizer',
					'fields' => array(
						'chankhe_aboutus_bg_type',
						'chankhe_aboutus_bg_color',
						'chankhe_aboutus_bg_gradient',
						'chankhe_aboutus_bg_image',
						'chankhe_aboutus_bg_video',
						'chankhe_aboutus_text_color',
					),
				),
				array(
					'name' => esc_html__( 'Advance', 'chankhe'),
					'icon' => 'admin-settings',
					'fields' => array(
						'chankhe_aboutus_margin_msg',
						'chankhe_aboutus_margin',
						'chankhe_aboutus_padding',
						'chankhe_aboutus_alignment',
					)
				),
			),
		)));  

		// About Us Top Title.
		$wp_customize->add_setting('chankhe_aboutus_top_title', array(
			'sanitize_callback'	=> 'sanitize_text_field'		//done
		));

		$wp_customize->add_control( 'chankhe_aboutus_top_title', array(
			'label'	   => esc_html__('Enter Top Title','chankhe'),
			'section'  => 'chankhe_aboutus_section',
			'type'	   => 'text',
		));

		// About Us Page.
		$wp_customize->add_setting( 'chankhe_aboutus', array(
			'sanitize_callback' => 'absint'			//done
		) );

		$wp_customize->add_control( 'chankhe_aboutus', array(
			'label'    => esc_html__( 'Select Page ', 'chankhe' ),
			'section'  => 'chankhe_aboutus_section',
			'type'     => 'dropdown-pages'
		));

		$wp_customize->selective_refresh->add_partial( 'chankhe_aboutus', array(
			'settings' => array( 'chankhe_aboutus' ),
			'selector' => "#about_us_front .about_title",
			'container_inclusive' => false
		));

		// About Us Image.
		$wp_customize->add_setting('chankhe_aboutus_image', array(
			'sanitize_callback'	=> 'absint'		//done
		));

		$wp_customize->add_control(new WP_Customize_Cropped_Image_Control($wp_customize, 'chankhe_aboutus_image', array(
			'label'	   => esc_html__('Upload About Features Image','chankhe'),
			'section'  => 'chankhe_aboutus_section',
			'width'    => 600,
	        'height'   => 600,
		)));

		$wp_customize->add_setting('chankhe_about_us_upgrade_text', array(
			'sanitize_callback' => 'sanitize_text_field'
		));
	
		$wp_customize->add_control(new Chankhe_Upgrade_Text($wp_customize, 'chankhe_about_us_upgrade_text', array(
			'section' 	=> 'chankhe_aboutus_section',
			'label' 	=> esc_html__('For more settings,', 'chankhe'),
			'choices' 	=> array(
				esc_html__('Choose different title styles', 'chankhe'),
				esc_html__('Upgrade with different layouts', 'chankhe'),
				esc_html__('Video Background Option', 'chankhe'),
			),
			'priority' => 100
		)));


	/**
	 * Video Call To Action Section
	*/
	$wp_customize->add_section('chankhe_video_calltoaction_section', array(
		'title'		=> esc_html__('Video Call To Action Section','chankhe'),
		'panel'		=> 'chankhe_frontpage_settings',
		'priority'  => chankhe_get_section_position('chankhe_video_calltoaction_section')
	));

		/**
         * Enable/Disable Option
         *
         * @since 1.0.0
        */
        $wp_customize->add_setting('chankhe_video_cta_service_section', array(
		    'default' => 'enable',
			'transport' => 'postMessage',
		    'sanitize_callback' => 'chankhe_sanitize_switch',     //done
		));

		$wp_customize->add_control(new Chankhe_Switch_Control($wp_customize, 'chankhe_video_cta_service_section', array(
		    'label' => esc_html__('Enable / Disable', 'chankhe'),
		    'section' => 'chankhe_video_calltoaction_section',
		    'switch_label' => array(
		        'enable' => esc_html__('Yes', 'chankhe'),
		        'disable' => esc_html__('No', 'chankhe'),
		    ),
		)));

		$wp_customize->selective_refresh->add_partial( 'chankhe_video_cta_service_section', array(
			'settings' => array( 'chankhe_video_cta_service_section' ),
			'selector' => "#calltoactionvideo_promo_wrapper",
			'container_inclusive' => false,
			'render_callback' => function() {
				return get_template_part( 'section/section', 'video_calltoaction' );
			},
		));


		$wp_customize->add_setting('chankhe_video_calltoaction_nav', array(
			'sanitize_callback' => 'wp_kses_post',
		));
		$wp_customize->add_control(new Chankhe_Custom_Control_Tab($wp_customize, 'chankhe_video_calltoaction_nav', array(
			'type' => 'tab',
			'priority' => 1,
			'section' => 'chankhe_video_calltoaction_section',
			'buttons' => array(
				array(
					'name' => esc_html__('Content', 'chankhe'),
					'icon' => 'welcome-widgets-menus',
					'fields' => array(
						'chankhe_video_calltoaction_top_title',
						'chankhe_cta_page',
						'chankhe_video_button_url',
						'chankhe_video_calltoaction_title',
						'chankhe_video_calltoaction_subtitle',
						'chankhe_video_cta_button_text',
						'chankhe_video_cta_button_url',
					),
					'active' => true,
				),
				array(
					'name' => esc_html__('Style', 'chankhe'),
					'icon' => 'admin-customizer',
					'fields' => array(
						'chankhe_video_calltoaction_bg_type',
						'chankhe_video_calltoaction_bg_color',
						'chankhe_video_calltoaction_bg_gradient',
						'chankhe_video_calltoaction_bg_image',
						'chankhe_video_calltoaction_bg_video',
						'chankhe_video_calltoaction_text_color',
					),
				),
				array(
					'name' => esc_html__( 'Extra', 'chankhe'),
					'icon' => 'admin-settings',
					'fields' => array(
						'chankhe_video_calltoaction_margin_msg',
						'chankhe_video_calltoaction_margin',
						'chankhe_video_calltoaction_padding',
						'chankhe_video_calltoaction_alignment',
					)
				),
			),
		)));

	
		// Video Call To Action Top Title.
		$wp_customize->add_setting('chankhe_video_calltoaction_top_title', array(
			'sanitize_callback'	=> 'sanitize_text_field'		//done
		));
		$wp_customize->add_control( 'chankhe_video_calltoaction_top_title', array(
			'label'	   => esc_html__('Section Top Title','chankhe'),
			'section'  => 'chankhe_video_calltoaction_section',
			'type'	   => 'text',
		));

		// Video Call To Action Page.
		$wp_customize->add_setting( 'chankhe_cta_page', array(
			'sanitize_callback' => 'absint'			//done
		));
		$wp_customize->add_control( 'chankhe_cta_page', array(
			'label'    => esc_html__( 'Select Page ', 'chankhe' ),
			'section'  => 'chankhe_video_calltoaction_section',
			'type'     => 'dropdown-pages'
		));

		$wp_customize->selective_refresh->add_partial( 'chankhe_cta_page', array(
			'settings' => array( 'chankhe_cta_page' ),
			'selector' => "#calltoactionvideo_promo_wrapper .about_title",
			'container_inclusive' => false,
		));

		// Call To Action Video Button URL.
		$wp_customize->add_setting('chankhe_video_button_url', array(
			'sanitize_callback'	=> 'esc_url_raw'		//done
		));
		$wp_customize->add_control('chankhe_video_button_url', array(
			'label'	   => esc_html__('Enter Youtube Video URL','chankhe'),
			'section'  => 'chankhe_video_calltoaction_section',
			'type'	   => 'url'
		));

		// Video Call To Action Title.
		$wp_customize->add_setting('chankhe_video_calltoaction_title', array(
			'sanitize_callback'	=> 'sanitize_text_field'		//done
		));
		$wp_customize->add_control( 'chankhe_video_calltoaction_title', array(
			'label'	   => esc_html__('Enter Section Title','chankhe'),
			'section'  => 'chankhe_video_calltoaction_section',
			'type'	   => 'text',
		));

		// Video Call To Action Subtitle.
		$wp_customize->add_setting('chankhe_video_calltoaction_subtitle', array(
			'sanitize_callback'	=> 'sanitize_text_field'		//done
		));
		$wp_customize->add_control('chankhe_video_calltoaction_subtitle', array(
			'label'	   => esc_html__('Enter Section Subtitle','chankhe'),
			'section'  => 'chankhe_video_calltoaction_section',
			'type'	   => 'text',
		));


		// Video Call To Action Button Text
		$wp_customize->add_setting('chankhe_video_cta_button_text', array(
			'sanitize_callback'	=> 'sanitize_text_field',		//done
			'default'	   => esc_html__('Call For Booking','chankhe'),
		));
		$wp_customize->add_control( 'chankhe_video_cta_button_text', array(
			'label'	   => esc_html__('Button Text','chankhe'),
			'section'  => 'chankhe_video_calltoaction_section',
			'type'	   => 'text',
		));

		// Call To Action Button URL
		$wp_customize->add_setting('chankhe_video_cta_button_url', array(
			'sanitize_callback'	=> 'esc_url_raw'		//done
		));
		$wp_customize->add_control('chankhe_video_cta_button_url', array(
			'label'	   => esc_html__('Button URL','chankhe'),
			'section'  => 'chankhe_video_calltoaction_section',
			'type'	   => 'url'
		));


	/**
	 * Our Service Section 
	*/
	$wp_customize->add_section('chankhe_service_section', array(
		'title'		=> esc_html__('Our Service Section','chankhe'),
		'panel'		=> 'chankhe_frontpage_settings',
		'priority'  => chankhe_get_section_position('chankhe_service_section')
	));

		/**
         * Enable/Disable Option
         *
         * @since 1.0.0
        */
        $wp_customize->add_setting('chankhe_service_service_section', array(
		    'default' => 'enable',
		    'sanitize_callback' => 'chankhe_sanitize_switch',     //done
		));

		$wp_customize->add_control(new Chankhe_Switch_Control($wp_customize, 'chankhe_service_service_section', array(
		    'label' => esc_html__('Enable / Disable', 'chankhe'),
		    'section' => 'chankhe_service_section',
		    'switch_label' => array(
		        'enable' => esc_html__('Yes', 'chankhe'),
		        'disable' => esc_html__('No', 'chankhe'),
		    ),
		)));

		$wp_customize->selective_refresh->add_partial( 'chankhe_service_service_section', array(
			'settings' => array( 'chankhe_service_service_section' ),
			'selector' => "#chankheservices",
			'container_inclusive' => true,
			'render_callback' => function() {
				return get_template_part( 'section/section', 'service' );
			},
		));



		$wp_customize->add_setting('chankhe_service_nav', array(
			'sanitize_callback' => 'wp_kses_post',
		));
		$wp_customize->add_control(new Chankhe_Custom_Control_Tab($wp_customize, 'chankhe_service_nav', array(
			'type' => 'tab',
			'priority' => 1,
			'section' => 'chankhe_service_section',
			'buttons' => array(
				array(
					'name' => esc_html__('Content', 'chankhe'),
					'icon' => 'welcome-widgets-menus',
					'fields' => array(
						'chankhe_service_title',
						'chankhe_service_sub_title',
						'chankhe_service',
						'chankhe_service_button',
						'chankhe_service_bg_color',
						'chankhe_service_text_color',
					),
					'active' => true,
				),
				array(
					'name' => esc_html__('Style', 'chankhe'),
					'icon' => 'admin-customizer',
					'fields' => array(
						'chankhe_service_bg_type',
						'chankhe_service_bg_color',
						'chankhe_service_bg_gradient',
						'chankhe_service_bg_image',
						'chankhe_service_bg_video',
						'chankhe_service_text_color',
					),
				),
				array(
					'name' => esc_html__( 'Extra', 'chankhe'),
					'icon' => 'admin-settings',
					'fields' => array(
						'chankhe_service_margin_msg',
						'chankhe_service_margin',
						'chankhe_service_padding',
						'chankhe_service_alignment',
					)
				),
			),
		)));


		// Our Service Section Title.
		$wp_customize->add_setting( 'chankhe_service_title', array(
			'sanitize_callback' => 'sanitize_text_field'			//done
		) );

		$wp_customize->add_control( 'chankhe_service_title', array(
			'label'    => esc_html__( 'Enter Service Section Title', 'chankhe' ),
			'section'  => 'chankhe_service_section',
			'type'     => 'text',
		));


		// Our Service Section Sub Title.
		$wp_customize->add_setting( 'chankhe_service_sub_title', array(
			'sanitize_callback' => 'sanitize_text_field'			//done
		) );

		$wp_customize->add_control( 'chankhe_service_sub_title', array(
			'label'    => esc_html__( 'Enter Service Section Sub Title', 'chankhe' ),
			'section'  => 'chankhe_service_section',
			'type'     => 'text',
		));

		//  Our Service Page.
		$wp_customize->add_setting('chankhe_service', array(
		    'sanitize_callback' => 'chankhe_sanitize_repeater',		//done
		    'default' => json_encode(array(
		        array(
		            'service_page' => '',
		        )
		    ))
		));

		$wp_customize->add_control(new Chankhe_Repeater_Control( $wp_customize,
			'chankhe_service', 

			array(
			    'label' 	   => esc_html__('Our Service Settings', 'chankhe'),
			    'section' 	   => 'chankhe_service_section',
			    'settings' 	   => 'chankhe_service',
			    'box_label' => esc_html__('Service Settings Options', 'chankhe'),
			    'add_label' => esc_html__('Add New Page', 'chankhe'),
			),
		    array(
		        'service_page' => array(
		            'type' => 'select',
		            'label' => esc_html__('Select Service Page', 'chankhe'),
		            'options' => $pages
		        )
			)
		));

		$wp_customize->selective_refresh->add_partial( 'chankhe_service', array(
			'settings' => array( 'chankhe_service' ),
			'selector' => "#chankheservices .box",
			'container_inclusive' => true
		));
		// Our Service Section Button text.
		$wp_customize->add_setting( 'chankhe_service_button', array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html__( 'Read More', 'chankhe' ),		//done
		) );

		$wp_customize->add_control( 'chankhe_service_button', array(
			'label'    => esc_html__( 'Enter Services Button Text', 'chankhe' ),
			'section'  => 'chankhe_service_section',
			'type'     => 'text',
		));

		// Services Section Background Color
		$wp_customize->add_setting('chankhe_service_bg_color', array(
		    'default' => '#004A8D',
		    'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control('chankhe_service_bg_color', array(
		    'type' => 'color',
		    'label' => esc_html__('Services Background Color', 'chankhe'),
		    'section' => 'chankhe_service_section',
		));


		// Services Section Text Color
		$wp_customize->add_setting('chankhe_service_text_color', array(
		    'default' => '#ffffff',
		    'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control('chankhe_service_text_color', array(
		    'type' => 'color',
		    'label' => esc_html__('Services Fonts Color', 'chankhe'),
		    'section' => 'chankhe_service_section',
		));

	/**
	 * Counter Section. 
	*/
	$wp_customize->add_section('chankhe_counter_section', array(
		'title'		=> 	esc_html__('Counter Section','chankhe'),
		'panel'		=> 'chankhe_frontpage_settings',
		'priority'  => chankhe_get_section_position('chankhe_counter_section')
	));

		/**
         * Enable/Disable Option
         *
         * @since 1.0.0
        */
        $wp_customize->add_setting('chankhe_counter_section', array(
		    'default' => 'enable',
			'transport' => 'postMessage',
		    'sanitize_callback' => 'chankhe_sanitize_switch',     //done
		));

		$wp_customize->add_control(new Chankhe_Switch_Control($wp_customize, 'chankhe_counter_section', array(
		    'label' => esc_html__('Enable / Disable', 'chankhe'),
		    'section' => 'chankhe_counter_section',
		    'switch_label' => array(
		        'enable' => esc_html__('Yes', 'chankhe'),
		        'disable' => esc_html__('No', 'chankhe'),
		    ),
		)));

		$wp_customize->selective_refresh->add_partial( 'chankhe_counter_section', array(
			'settings' => array( 'chankhe_counter_section' ),
			'selector' => "#chankhecounter_wrap",
			'container_inclusive' => true,
			'render_callback' => function() {
				return get_template_part( 'section/section', 'counter' );
			},
		));


		$wp_customize->add_setting('chankhe_counter_nav', array(
			'sanitize_callback' => 'wp_kses_post',
		));
		$wp_customize->add_control(new Chankhe_Custom_Control_Tab($wp_customize, 'chankhe_counter_nav', array(
			'type' => 'tab',
			'priority' => 1,
			'section' => 'chankhe_counter_section',
			'buttons' => array(
				array(
					'name' => esc_html__('Content', 'chankhe'),
					'icon' => 'welcome-widgets-menus',
					'fields' => array(
						'chankhe_counter_title',
						'chankhe_counter_sub_title',
						'chankhe_counter'
					),
					'active' => true,
				),
				array(
					'name' => esc_html__('Style', 'chankhe'),
					'icon' => 'admin-customizer',
					'fields' => array(
						'chankhe_counter_bg_type',
						'chankhe_counter_bg_color',
						'chankhe_counter_bg_gradient',
						'chankhe_counter_bg_image',
						'chankhe_counter_bg_video',
						'chankhe_counter_text_color',
					),
				),
				array(
					'name' => esc_html__( 'Extra', 'chankhe'),
					'icon' => 'admin-settings',
					'fields' => array(
						'chankhe_counter_margin_msg',
						'chankhe_counter_margin',
						'chankhe_counter_padding',
						'chankhe_counter_alignment',
					)
				),
			),
		)));

		// Counter Section Title.
		$wp_customize->add_setting('chankhe_counter_title', array(
			'sanitize_callback'	=> 'sanitize_text_field'		//done
		));

		$wp_customize->add_control('chankhe_counter_title', array(
			'label'	   => esc_html__('Enter Section Title','chankhe'),
			'section'  => 'chankhe_counter_section',
			'type'	   => 'text',
		));

		$wp_customize->selective_refresh->add_partial( 'chankhe_counter_title', array(
			'settings' => array( 'chankhe_counter_title' ),
			'selector' => "#chankhecounter_wrap .about_title",
			'container_inclusive' => true
		));


		// Our Service Section Sub Title.
		$wp_customize->add_setting( 'chankhe_counter_sub_title', array(
			'sanitize_callback' => 'sanitize_text_field'			//done
		) );

		$wp_customize->add_control( 'chankhe_counter_sub_title', array(
			'label'    => esc_html__( 'Enter Service Section Sub Title', 'chankhe' ),
			'section'  => 'chankhe_counter_section',
			'type'     => 'text',
		));


		// Counter Section.
		$wp_customize->add_setting('chankhe_counter', array(
		    'sanitize_callback' => 'chankhe_sanitize_repeater',		//done
		    'default' => json_encode(array(
		        array(
		            'counter_title'  =>'',
		            'counter_number'  =>'',	            
		        )
		    ))
		));

		$wp_customize->add_control(new Chankhe_Repeater_Control( $wp_customize, 
			'chankhe_counter', 

			array(
			    'label' 	   => esc_html__('Counter Settings', 'chankhe'),
			    'section' 	   => 'chankhe_counter_section',
			    'settings' 	   => 'chankhe_counter',
			    'box_label' => esc_html__('Counter Settings Options', 'chankhe'),
			    'add_label' => esc_html__('Add New', 'chankhe'),
			),

		    array(

		        'counter_title' => array(
		            'type' => 'text',
		            'label' => esc_html__('Enter Counter Title', 'chankhe'),
		            'default' => ''
		        ),

		        'counter_number' => array(
		            'type' => 'text',
		            'label' => esc_html__('Enter Counter Number', 'chankhe'),
		            'default' => ''
		        ),
		        
			)
		));



	/* Blog Section. */
	$wp_customize->add_section('chankhe_blog_section', array(
		'title'		=> 	esc_html__('Blog Section','chankhe'),
		'panel'		=> 'chankhe_frontpage_settings',
		'priority'  => chankhe_get_section_position('chankhe_blog_section')
	));

		/**
         * Enable/Disable Option
         *
         * @since 1.0.0
        */
        $wp_customize->add_setting('chankhe_home_blog_section', array(
		    'default' => 'enable',
			'transport' => 'postMessage',
		    'sanitize_callback' => 'chankhe_sanitize_switch',     //done
		));

		$wp_customize->add_control(new Chankhe_Switch_Control($wp_customize, 'chankhe_home_blog_section', array(
		    'label' => esc_html__('Enable / Disable', 'chankhe'),
		    'section' => 'chankhe_blog_section',
		    'switch_label' => array(
		        'enable' => esc_html__('Yes', 'chankhe'),
		        'disable' => esc_html__('No', 'chankhe'),
		    ),
		)));
		$wp_customize->selective_refresh->add_partial( 'chankhe_home_blog_section', array(
			'settings' => array( 'chankhe_home_blog_section' ),
			'selector' => "#chankheblog",
			'container_inclusive' => true,
			'render_callback' => function() {
				return get_template_part( 'section/section', 'blog' );
			},
		));


		$wp_customize->add_setting('chankhe_home_blog_nav', array(
			'sanitize_callback' => 'wp_kses_post',
		));
		$wp_customize->add_control(new Chankhe_Custom_Control_Tab($wp_customize, 'chankhe_home_blog_nav', array(
			'type' => 'tab',
			'priority' => 1,
			'section' => 'chankhe_blog_section',
			'buttons' => array(
				array(
					'name' => esc_html__('Content', 'chankhe'),
					'icon' => 'welcome-widgets-menus',
					'fields' => array(
						'chankhe_blog_title',
						'chankhe_blog_sub_title',
						'chankhe_blog',
						'chankhe_posts_num'
					),
					'active' => true,
				),
				array(
					'name' => esc_html__('Style', 'chankhe'),
					'icon' => 'admin-customizer',
					'fields' => array(
						'chankhe_blog_bg_type',
						'chankhe_blog_bg_color',
						'chankhe_blog_bg_gradient',
						'chankhe_blog_bg_image',
						'chankhe_blog_bg_video',
						'chankhe_blog_text_color',
					),
				),
				array(
					'name' => esc_html__( 'Extra', 'chankhe'),
					'icon' => 'admin-settings',
					'fields' => array(
						'chankhe_blog_margin_msg',
						'chankhe_blog_margin',
						'chankhe_blog_padding',
						'chankhe_blog_alignment',
					)
				),
			),
		)));

		// Blog Title.
		$wp_customize->add_setting('chankhe_blog_title', array(
			'sanitize_callback'	=> 'sanitize_text_field'		//done
		));

		$wp_customize->add_control('chankhe_blog_title', array(
			'label'	   => esc_html__('Enter Section Title','chankhe'),
			'section'  => 'chankhe_blog_section',
			'type'	   => 'text',
		));

		// Our Service Section Sub Title.
		$wp_customize->add_setting( 'chankhe_blog_sub_title', array(
			'sanitize_callback' => 'sanitize_text_field'			//done
		) );

		$wp_customize->add_control( 'chankhe_blog_sub_title', array(
			'label'    => esc_html__( 'Enter Service Section Sub Title', 'chankhe' ),
			'section'  => 'chankhe_blog_section',
			'type'     => 'text',
		));

		// Blog Posts.
		$wp_customize->add_setting('chankhe_blog', array(
		    'sanitize_callback' => 'sanitize_text_field',     //done
		));

		$wp_customize->add_control(new Chankhe_Multiple_Check_Control($wp_customize, 'chankhe_blog', array(
		    'label'    => esc_html__('Select Category To Show Posts', 'chankhe'),
		    'settings' => 'chankhe_blog',
		    'section'  => 'chankhe_blog_section',
		    'choices'  => $blog_cat,
		)));

		$wp_customize->selective_refresh->add_partial( 'chankhe_blog', array(
			'settings' => array( 'chankhe_blog' ),
			'selector' => "#chankheblog .box",
			'container_inclusive' => true
		));

		// Select Blog Post Layout.
		$wp_customize->add_setting('chankhe_posts_num',array(
			'default'			 =>	'three',
			'sanitize_callback'	 =>	'chankhe_sanitize_select'		//done	
		));

		$wp_customize->add_control( 'chankhe_posts_num', array(
			'label'	  =>	esc_html__('Select Number Of Blog Posts To Display','chankhe'),
			'section' =>	'chankhe_blog_section',
			'type'	  =>	'select',
			'choices' => array(
				'three' => esc_html__('3 Column Layout','chankhe'),
				'six'   => esc_html__( '6 Column Layout','chankhe' ),
			)
		));


	/* Testimonial Section. */
	$wp_customize->add_section('chankhe_testimonial_section', array(
		'title'		=> 	esc_html__('Testimonial Section','chankhe'),
		'panel'		=> 'chankhe_frontpage_settings',
		'priority'  => chankhe_get_section_position('chankhe_testimonial_section')
	));

		/**
         * Enable/Disable Option
         *
         * @since 1.0.0
        */
        $wp_customize->add_setting('chankhe_testimonial_options', array(
		    'default' => 'enable',
			'transport' => 'postMessage',
		    'sanitize_callback' => 'chankhe_sanitize_switch',     //done
		));

		$wp_customize->add_control(new Chankhe_Switch_Control($wp_customize, 'chankhe_testimonial_options', array(
		    'label' => esc_html__('Enable / Disable', 'chankhe'),
		    'section' => 'chankhe_testimonial_section',
		    'switch_label' => array(
		        'enable' => esc_html__('Yes', 'chankhe'),
		        'disable' => esc_html__('No', 'chankhe'),
		    ),
		)));

		$wp_customize->selective_refresh->add_partial( 'chankhe_testimonial_options', array(
			'settings' => array( 'chankhe_testimonial_options' ),
			'selector' => "#chankhetestimonial",
			'container_inclusive' => true,
			'render_callback' => function() {
				return get_template_part( 'section/section', 'testimonial' );
			},
		));


		$wp_customize->add_setting('chankhe_testimonial_nav', array(
			'sanitize_callback' => 'wp_kses_post',
		));
		$wp_customize->add_control(new Chankhe_Custom_Control_Tab($wp_customize, 'chankhe_testimonial_nav', array(
			'type' => 'tab',
			'priority' => 1,
			'section' => 'chankhe_testimonial_section',
			'buttons' => array(
				array(
					'name' => esc_html__('Content', 'chankhe'),
					'icon' => 'welcome-widgets-menus',
					'fields' => array(
						'chankhe_testimonial_title',
						'chankhe_testimonial_sub_title',
						'chankhe_testimonials',
					),
					'active' => true,
				),
				array(
					'name' => esc_html__('Style', 'chankhe'),
					'icon' => 'admin-customizer',
					'fields' => array(
						'chankhe_testimonial_bg_type',
						'chankhe_testimonial_bg_color',
						'chankhe_testimonial_bg_gradient',
						'chankhe_testimonial_bg_image',
						'chankhe_testimonial_bg_video',
						'chankhe_testimonial_text_color',
					),
				),
				array(
					'name' => esc_html__( 'Extra', 'chankhe'),
					'icon' => 'admin-settings',
					'fields' => array(
						'chankhe_testimonial_margin_msg',
						'chankhe_testimonial_margin',
						'chankhe_testimonial_padding',
						'chankhe_testimonial_alignment',
					)
				),
			),
		)));


		// Blog Title.
		$wp_customize->add_setting('chankhe_testimonial_title', array(
			'sanitize_callback'	=> 'sanitize_text_field'		//done
		));

		$wp_customize->add_control('chankhe_testimonial_title', array(
			'label'	   => esc_html__('Enter Section Title','chankhe'),
			'section'  => 'chankhe_testimonial_section',
			'type'	   => 'text',
		));

		// Our Service Section Sub Title.
		$wp_customize->add_setting( 'chankhe_testimonial_sub_title', array(
			'sanitize_callback' => 'sanitize_text_field'			//done
		) );

		$wp_customize->add_control( 'chankhe_testimonial_sub_title', array(
			'label'    => esc_html__( 'Enter Service Section Sub Title', 'chankhe' ),
			'section'  => 'chankhe_testimonial_section',
			'type'     => 'text',
		));

		//  Testimonial Page.
		$wp_customize->add_setting('chankhe_testimonials', array(
		    'sanitize_callback' => 'chankhe_sanitize_repeater',		//done
		    'default' => json_encode(array(
		        array(
		            'testimonial_page' => '',
					'designation_title'  =>'',
		        )
		    ))
		));

		$wp_customize->add_control(new Chankhe_Repeater_Control( $wp_customize, 
			'chankhe_testimonials', 

			array(
			    'label' 	   => esc_html__('Testimonials Settings', 'chankhe'),
			    'section' 	   => 'chankhe_testimonial_section',
			    'settings' 	   => 'chankhe_testimonials',
			    'box_label' => esc_html__('Testimonial Settings Options', 'chankhe'),
			    'add_label' => esc_html__('Add New Page', 'chankhe'),
			),
		    array(
		        'testimonial_page' => array(
		            'type' => 'select',
		            'label' => esc_html__('Select Testimonial Page', 'chankhe'),
		            'options' => $pages
		        ),
				'designation_title' => array(
		            'type' => 'text',
		            'label' => esc_html__('Designation', 'chankhe'),
		            'default' => ''
		        ),
			)
		));

		$wp_customize->selective_refresh->add_partial( 'chankhe_testimonials', array(
			'settings' => array( 'chankhe_testimonials' ),
			'selector' => "#chankhetestimonial .testimonialbox",
			'container_inclusive' => true,
		));

	/* Team Section. */
	$wp_customize->add_section('chankhe_team_section', array(
		'title'		=> 	esc_html__('Our Team Section','chankhe'),
		'panel'		=> 'chankhe_frontpage_settings',
		'priority'  => chankhe_get_section_position('chankhe_team_section')
	));

		/**
         * Enable/Disable Option
         *
         * @since 1.0.0
        */
        $wp_customize->add_setting('chankhe_team_options', array(
		    'default' => 'enable',
			'transport' => 'postMessage',
		    'sanitize_callback' => 'chankhe_sanitize_switch',     //done
		));

		$wp_customize->add_control(new Chankhe_Switch_Control($wp_customize, 'chankhe_team_options', array(
		    'label' => esc_html__('Enable / Disable', 'chankhe'),
		    'section' => 'chankhe_team_section',
		    'switch_label' => array(
		        'enable' => esc_html__('Yes', 'chankhe'),
		        'disable' => esc_html__('No', 'chankhe'),
		    ),
		)));

		$wp_customize->selective_refresh->add_partial( 'chankhe_team_options', array(
			'settings' => array( 'chankhe_team_options' ),
			'selector' => "#chankheteam",
			'container_inclusive' => true,
			'render_callback' => function() {
				return get_template_part( 'section/section', 'team' );
			},
		));


		$wp_customize->add_setting('chankhe_team_nav', array(
			'sanitize_callback' => 'wp_kses_post',
		));
		$wp_customize->add_control(new Chankhe_Custom_Control_Tab($wp_customize, 'chankhe_team_nav', array(
			'type' => 'tab',
			'priority' => 1,
			'section' => 'chankhe_team_section',
			'buttons' => array(
				array(
					'name' => esc_html__('Content', 'chankhe'),
					'icon' => 'welcome-widgets-menus',
					'fields' => array(
						'chankhe_team_title',
						'chankhe_team_sub_title',
						'chankhe_team',
					),
					'active' => true,
				),
				array(
					'name' => esc_html__('Style', 'chankhe'),
					'icon' => 'admin-customizer',
					'fields' => array(
						'chankhe_team_bg_type',
						'chankhe_team_bg_color',
						'chankhe_team_bg_gradient',
						'chankhe_team_bg_image',
						'chankhe_team_bg_video',
						'chankhe_team_text_color',
					),
				),
				array(
					'name' => esc_html__( 'Extra', 'chankhe'),
					'icon' => 'admin-settings',
					'fields' => array(
						'chankhe_team_margin_msg',
						'chankhe_team_margin',
						'chankhe_team_padding',
						'chankhe_team_alignment',
					)
				),
			),
		)));

		// Team Section Title.
		$wp_customize->add_setting( 'chankhe_team_title', array(
			'sanitize_callback' => 'sanitize_text_field'			//done
		) );

		$wp_customize->add_control( 'chankhe_team_title', array(
			'label'    => esc_html__( 'Enter Section Title', 'chankhe' ),
			'section'  => 'chankhe_team_section',
			'type'     => 'text',
		));

		// Our Service Section Sub Title.
		$wp_customize->add_setting( 'chankhe_team_sub_title', array(
			'sanitize_callback' => 'sanitize_text_field'			//done
		) );

		$wp_customize->add_control( 'chankhe_team_sub_title', array(
			'label'    => esc_html__( 'Enter Service Section Sub Title', 'chankhe' ),
			'section'  => 'chankhe_team_section',
			'type'     => 'text',
		));

		// Our Team Page.
		$wp_customize->add_setting('chankhe_team', array(
		    'sanitize_callback' => 'chankhe_sanitize_repeater',		//done
		    'default' => json_encode(array(
		        array(
		            'team_page'   => '',
		            'facebook'    =>'',
		            'twitter'     =>'',
		            'linkedin'      =>'',
		            'instagram'   => '',
		        )
		    ))
		));

		$wp_customize->add_control(new Chankhe_Repeater_Control( $wp_customize, 
			'chankhe_team', 
			array(
			    'label' 	   => esc_html__('Team Settings', 'chankhe'),
			    'section' 	   => 'chankhe_team_section',
			    'settings' 	   => 'chankhe_team',
			    'box_label' => esc_html__('Team Setting Options', 'chankhe'),
			    'add_label' => esc_html__('Add New Page', 'chankhe'),
			),
		    array(

		        'team_page' => array(
		            'type'    => 'select',
		            'label'   => esc_html__('Select Team Page', 'chankhe'),
		            'options' => $pages
		        ),

		        'facebook'  => array(
		            'type'   => 'url',
		            'label'  => esc_html__('Enter Facebook Link', 'chankhe'),
		            'default' => ''
		        ),

		        'twitter' 	=> array(
		            'type'    => 'url',
		            'label'   => esc_html__('Enter Twitter Link', 'chankhe'),
		            'default' => ''
		        ),

		        'linkedin'   => array(
		            'type'    => 'url',
		            'label'   => esc_html__('Enter Linkedin Link', 'chankhe'),
		            'default' => ''
		        ),
		        
		        'instagram' => array(
		            'type'    => 'url',
		            'label'   => esc_html__('Enter Instagram Link', 'chankhe'),
		            'default' => ''
		        )
			)
		));

		$wp_customize->selective_refresh->add_partial( 'chankhe_team', array(
			'settings' => array( 'chankhe_team' ),
			'selector' => "#chankheteam .teamwrap",
			'container_inclusive' => true
		));


	/**
	 * Theme Option Settings.
	*/
	$wp_customize->add_panel('chankhe_theme_options', array(
		'title'		=>	esc_html__('Theme Options','chankhe'),
		'priority'	=>	55,
	));

		// Site Layout.
		$wp_customize->add_section('chankhe_site_layout_section', array(
			'title'		=>	esc_html__('Site Layout','chankhe'),
			'panel'		=> 'chankhe_theme_options',
		));

			// Site Layout Options.
			$wp_customize->add_setting('chankhe_site_layout', array(
				'default' => 'boxed',
				'sanitize_callback' => 'chankhe_sanitize_select'         //done
			));

			$wp_customize->add_control('chankhe_site_layout', array(
				'label'   => esc_html__('Site Layout','chankhe'),
				'section' => 'chankhe_site_layout_section',
				'type'    => 'select',
				'choices' => array(
					'full_width' => esc_html__('Full Width','chankhe'),
					'boxed' => esc_html__('Boxed','chankhe'),			
				)
			));

			/** page container width in % */
			$wp_customize->add_setting("chankhe_page_width", array(
				'sanitize_callback' => 'chankhe_sanitize_number_blank',
				'default' => 90,
				// 'transport' => 'postMessage'
			));
			$wp_customize->add_setting("chankhe_page_width_tablet", array(
				'sanitize_callback' => 'chankhe_sanitize_number_blank',
				'default' => '100',
				// 'transport' => 'postMessage'
			));
			$wp_customize->add_setting("chankhe_page_width_mobile", array(
				'sanitize_callback' => 'chankhe_sanitize_number_blank',
				'default' => '100',
				// 'transport' => 'postMessage'
			));

			$wp_customize->add_setting("chankhe_page_width_unit", array(
				'sanitize_callback' => 'sanitize_text_field',
				'default' => '%',
				// 'transport' => 'postMessage'
			));

			$wp_customize->add_control(new Chankhe_Range_Slider_Control($wp_customize, "chankhe_page_width_group", array(
				'section' => "chankhe_site_layout_section",
				'label' => esc_html__('Container Width', 'chankhe'),
				'input_attrs' => array(
					'min' => 70,
					'max' => 1920,
					'step' => 1,
				),
				'settings' => array(
					'desktop' => "chankhe_page_width",
					'tablet' => "chankhe_page_width_tablet",
					'mobile' => "chankhe_page_width_mobile",
					'unit' => "chankhe_page_width_unit"
				)
			)));

		
			/** box width */
			$wp_customize->add_setting("chankhe_page_box_width", array(
				'sanitize_callback' => 'chankhe_sanitize_number_blank',
				'default' => 90,
				// 'transport' => 'postMessage'
			));
			$wp_customize->add_setting("chankhe_page_box_width_tablet", array(
				'sanitize_callback' => 'chankhe_sanitize_number_blank',
				'default' => '100',
				// 'transport' => 'postMessage'
			));
			$wp_customize->add_setting("chankhe_page_box_width_mobile", array(
				'sanitize_callback' => 'chankhe_sanitize_number_blank',
				'default' => '100',
				// 'transport' => 'postMessage'
			));

			$wp_customize->add_setting("chankhe_page_box_width_unit", array(
				'sanitize_callback' => 'sanitize_text_field',
				'default' => '%',
				// 'transport' => 'postMessage'
			));

			$wp_customize->add_control(new Chankhe_Range_Slider_Control($wp_customize, "chankhe_page_box_width_group", array(
				'section' => "chankhe_site_layout_section",
				'label' => esc_html__('Box Width', 'chankhe'),
				'input_attrs' => array(
					'min' => 70,
					'max' => 1920,
					'step' => 1,
				),
				'settings' => array(
					'desktop' => "chankhe_page_box_width",
					'tablet' => "chankhe_page_box_width_tablet",
					'mobile' => "chankhe_page_box_width_mobile",
					'unit' => "chankhe_page_box_width_unit"
				)
			)));

			

		/**
		 * Page Layout Sidebar Options
		*/
		$wp_customize->add_section('chankhe_sidebar', array(
			'title'		=>	esc_html__('Page Sidebar Layout','chankhe'),
			'panel'		=> 'chankhe_theme_options',
		));

			
			// Blog Sidebar Options.
			$wp_customize->add_setting('chankhe_blog_sidebar', array(
			    'default' => 'right',
			    'sanitize_callback' => 'chankhe_sanitize_select',     //done
			));

			$wp_customize->add_control('chankhe_blog_sidebar', array(
			    'label'   => esc_html__('Index Blog Posts Sidebar', 'chankhe'),
			    'section' => 'chankhe_sidebar',
			    'type'    => 'select',
			    'choices' => array(
			        'right' => esc_html__('Content / Sidebar', 'chankhe'),
			        'left' => esc_html__('Sidebar / Content', 'chankhe'),
			        'no' => esc_html__('Full Width', 'chankhe'),
			    ),
			));

			// Blog Archive Sidebar Options.
			$wp_customize->add_setting('chankhe_archive_sidebar', array(
			    'default' => 'right',
			    'sanitize_callback' => 'chankhe_sanitize_select',     //done
			));

			$wp_customize->add_control('chankhe_archive_sidebar', array(
			    'label'   => esc_html__('Blog Archive Sidebar', 'chankhe'),
			    'section' => 'chankhe_sidebar',
			    'type'    => 'select',
			    'choices' => array(
			        'right' => esc_html__('Content / Sidebar', 'chankhe'),
			        'left' => esc_html__('Sidebar / Content', 'chankhe'),
			        'no' => esc_html__('Full Width', 'chankhe'),	        
			    ),
			));

			// Page Sidebar Options.
			$wp_customize->add_setting('chankhe_page_sidebar', array(
			    'default' => 'right',
			    'sanitize_callback' => 'chankhe_sanitize_select',     //done
			));

			$wp_customize->add_control('chankhe_page_sidebar', array(
			    'label'   => esc_html__('Page Sidebar', 'chankhe'),
			    'section' => 'chankhe_sidebar',
			    'type'    => 'select',
			    'choices' => array(
			        'right' => esc_html__('Content / Sidebar', 'chankhe'),
			        'left' => esc_html__('Sidebar / Content', 'chankhe'),
			        'no' => esc_html__('Full Width', 'chankhe'),	        
			    ),
			));

			// Search Page Sidebar Options.
			$wp_customize->add_setting('chankhe_search_sidebar', array(
			    'default' => 'right',
			    'sanitize_callback' => 'chankhe_sanitize_select',     //done
			));

			$wp_customize->add_control('chankhe_search_sidebar', array(
			    'label'   => esc_html__('Search Page Sidebar', 'chankhe'),
			    'section' => 'chankhe_sidebar',
			    'type'    => 'select',
			    'choices' => array(
			        'right' => esc_html__('Content / Sidebar', 'chankhe'),
			        'left' => esc_html__('Sidebar / Content', 'chankhe'),
			        'no' => esc_html__('Full Width', 'chankhe'),	        
			    ),
			));

		    


		/**
		 * Blog Template.
		*/
		$wp_customize->add_section('chankhe_blog_template', array(
			'title'		  => esc_html__('Blog Template Settings','chankhe'),
			'priority'	  => 65,
		));


			//  Blog Template Blog Posts by Category.
			$wp_customize->add_setting('chankhe_blogtemplate_postcat', array(
			    'sanitize_callback' => 'sanitize_text_field',     //done
			));

			$wp_customize->add_control(new chankhe_Multiple_Check_Control($wp_customize, 'chankhe_blogtemplate_postcat', array(
			    'label'    => esc_html__('Select Category To Show Posts', 'chankhe'),
			    'settings' => 'chankhe_blogtemplate_postcat',
			    'section'  => 'chankhe_blog_template',
			    'choices'  => $blog_cat,
			    'description' => esc_html__('Note: Selected Category Only Work When you can select page template (
			    	Blog Template )','chankhe'),
			)));



			// Blog Sidebar Options.
			$wp_customize->add_setting('chankhe_blog_template_sidebar', array(
			    'default' => 'right',
			    'sanitize_callback' => 'chankhe_sanitize_select',     //done
			));

			$wp_customize->add_control('chankhe_blog_template_sidebar', array(
			    'label'   => esc_html__('Blog Template Layout Settings', 'chankhe'),
			    'section' => 'chankhe_blog_template',
			    'type'    => 'select',
			    'description' => esc_html__('Note: Blog Template Layout Only Work When you can select page template ( Blog Template )','chankhe'),
			    'choices' => array(
			        'right' => esc_html__('Content / Sidebar', 'chankhe'),
			        'left' => esc_html__('Sidebar / Content', 'chankhe'),
			        'no' => esc_html__('Full Width', 'chankhe'),
			    ),
			));


		$post_layout = array(
	        'none'  => esc_html__( 'Normal Layout', 'chankhe' ),
	        'masonry2-rsidebar'  => esc_html__( 'Masonry Layout', 'chankhe' )
	    );

			// Blog Template Layout.
			$wp_customize->add_setting('chankhe_blogtemplate_layout', array(
				'default'		=>	'masonry2-rsidebar',
				'sanitize_callback'	=> 'chankhe_sanitize_select',	//done
			));

			$wp_customize->add_control('chankhe_blogtemplate_layout', array(
				'label'		=>	esc_html__('Post Display Layout','chankhe'),
				'section'	=> 'chankhe_blog_template',
				'type'		=> 'select',
				'choices' 	=> $post_layout
			));


		$post_description = array(
	        'none'     => esc_html__( 'None', 'chankhe' ),
	        'excerpt'  => esc_html__( 'Post Excerpt', 'chankhe' ),
	        'content'  => esc_html__( 'Post Content', 'chankhe' )
	    );
	        
	        $wp_customize->add_setting( 
	            'chankhe_post_description_options', 

	            array(
	                'default'           => 'excerpt',
	                'sanitize_callback' => 'chankhe_sanitize_select'
	            ) 
	        );
	        
	        $wp_customize->add_control( 
	            'chankhe_post_description_options', 

	            array(
	                'type' => 'select',
	                'label' => esc_html__( 'Post Description', 'chankhe' ),
	                'section' => 'chankhe_blog_template',
	                'choices' => $post_description
	            ) 
	        );


			// Blog Template Read More Button.
			$wp_customize->add_setting( 'chankhe_blogtemplate_btn', array(
				'default'           => esc_html__( 'Read More','chankhe' ),
				'sanitize_callback' => 'sanitize_text_field',		//done
			));

			$wp_customize->add_control('chankhe_blogtemplate_btn', array(
				'label'		  => esc_html__( 'Enter Blog Button Text', 'chankhe' ),
				'section'	  => 'chankhe_blog_template',
				'type' 		  => 'text',
			));


			/**
	         * Number field for Excerpt Length section
	         *
	         * @since 1.0.0
	         */
	        $wp_customize->add_setting(
	            'chankhe_post_excerpt_length',
	            array(
	                'default'    => 50,
	                'sanitize_callback' => 'absint'
	            )
	        );

	        $wp_customize->add_control(
	            'chankhe_post_excerpt_length',

	            array(
	                'type'      => 'number',
	                'label'     => esc_html__( 'Enter Posts Excerpt Length', 'chankhe' ),
	                'section'   => 'chankhe_blog_template',
	            )
	        );


	        /**
	         * Enable/Disable Option for Post Elements Date
	         *
	         * @since 1.0.0
	        */
	        $wp_customize->add_setting('chankhe_post_date_options', array(
			    'default' => 'enable',
			    'sanitize_callback' => 'chankhe_sanitize_switch',     //done
			));

			$wp_customize->add_control(new Chankhe_Switch_Control($wp_customize, 'chankhe_post_date_options', array(
			    'label' => esc_html__('Post Meta Date', 'chankhe'),
			    'settings' => 'chankhe_post_date_options',
			    'section' => 'chankhe_blog_template',
			    'switch_label' => array(
			        'enable' => esc_html__('Yes', 'chankhe'),
			        'disable' => esc_html__('No', 'chankhe'),
			    ),
			)));


	        /**
	         * Enable/Disable Option for Post Elements Comments
	         *
	         * @since 1.0.0
	         */
	        $wp_customize->add_setting('chankhe_post_comments_options', array(
			    'default' => 'enable',
			    'sanitize_callback' => 'chankhe_sanitize_switch',     //done
			));

			$wp_customize->add_control(new Chankhe_Switch_Control($wp_customize, 'chankhe_post_comments_options', array(
			    'label' => esc_html__('Post Meta Comments', 'chankhe'),
			    'settings' => 'chankhe_post_comments_options',
			    'section' => 'chankhe_blog_template',
			    'switch_label' => array(
			        'enable' => esc_html__('Yes', 'chankhe'),
			        'disable' => esc_html__('No', 'chankhe'),
			    ),
			)));


	        /**
	         * Enable/Disable Option for Post Elements Tags
	         *
	         * @since 1.0.0
	         */
	        $wp_customize->add_setting('chankhe_post_author_options', array(
			    'default' => 'enable',
			    'sanitize_callback' => 'chankhe_sanitize_switch',     //done
			));

			$wp_customize->add_control(new Chankhe_Switch_Control( $wp_customize, 'chankhe_post_author_options', array(
			    'label' => esc_html__('Post Meta Author', 'chankhe'),
			    'settings' => 'chankhe_post_author_options',
			    'section' => 'chankhe_blog_template',
			    'switch_label' => array(
			        'enable' => esc_html__('Yes', 'chankhe'),
			        'disable' => esc_html__('No', 'chankhe'),
			    ),
			)));

			/** common settings */
			require get_template_directory() . '/inc/customizer/common-settings.php';

}
add_action( 'customize_register', 'chankhe_customize_register' );


/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function chankhe_customize_partial_blogname() {

	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function chankhe_customize_partial_blogdescription() {

	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
*/
function chankhe_customize_preview_js() {

	wp_enqueue_script( 'chankhe-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'chankhe_customize_preview_js' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 *
 * Enqueue required scripts/styles for customizer panel
 *
 * @since 1.0.0
 *
 */
function chankhe_customize_scripts(){

    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/library/fontawesome/css/all.min.css');
	wp_enqueue_style('ico-fonts', get_template_directory_uri() . '/assets/css/icofont.css');

    wp_enqueue_style('chankhe-customizer', get_template_directory_uri() . '/assets/css/customizer.css');

    wp_enqueue_script('chankhe-customizer', get_template_directory_uri() . '/assets/js/customizer-admin.js', array('jquery', 'customize-controls'), true);
}
add_action('customize_controls_enqueue_scripts', 'chankhe_customize_scripts');



add_action('wp_ajax_chankhe_sections_reorder', 'chankhe_sections_reorder');

function chankhe_sections_reorder() {

    if (isset($_POST['sections'])) {

        set_theme_mod('chankhe_frontpage_sections', $_POST['sections']);
    }

    wp_die();
}

function chankhe_get_section_position($key) {

    $sections = chankhe_homepage_section();

    $position = array_search($key, $sections);

    $return = ( $position + 1 ) * 10;

    return $return;
}

if( !function_exists('chankhe_homepage_section') ){

	function chankhe_homepage_section(){

		$defaults = apply_filters('chankhe_homepage_sections',
			array(
				'chankhe_promoservice_section',
				'chankhe_aboutus_section',
				'chankhe_video_calltoaction_section',
				'chankhe_service_section',
				'chankhe_calltoaction_section',
				'chankhe_recentwork_section',
				'chankhe_counter_section',
				'chankhe_blog_section',
				'chankhe_testimonial_section',
				'chankhe_team_section'
			)
		);

		$sections = get_theme_mod('chankhe_frontpage_sections', $defaults);
		
        return $sections;
	}
}

