<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @subpackage Chankhe
 *
 * @since 1.0.0
 *
 */
if ( ! function_exists( 'chankhe_section_title' ) ){
    /**
     * Section Main Title
     *
     * @since 1.0.0
     */
    function chankhe_section_title( $title, $sub_title ) { 

        if( !empty( $title ) || !empty( $sub_title ) ){ ?>

            <div class="row">
                <div class="col-lg-12 col-sm-12 col-xs-12 chankhe-heading">

                    <?php if( !empty( $title ) ){ if( function_exists( 'pll_register_string' ) ){ ?>

                        <h2 class="section-title"><?php echo esc_html( pll__( $title ) ); ?></h2>

                    <?php }else{ ?>

                        <h2 class="section-title"><?php echo esc_html( $title ); ?></h2>

                    <?php } } if( !empty( $sub_title ) ){ if( function_exists( 'pll_register_string' ) ){ ?>

                          <div class="section-tagline"><?php echo esc_html( pll__( $sub_title ) ); ?></div>

                    <?php }else{ ?>

                            <div class="section-tagline"><?php echo esc_html( $sub_title ); ?></div>

                    <?php } } ?>

                </div>
            </div>
        <?php }
    }
}


if ( ! function_exists( 'chankhe_post_meta' ) ){
    /**
     * Post Meta Function
     *
     * @since 1.0.0
     */
    function chankhe_post_meta() { 
        
        $postdate    = get_theme_mod( 'chankhe_post_date_options', 'enable' );
        $postcomment = get_theme_mod( 'chankhe_post_comments_options', 'enable' );
        $postauthor  = get_theme_mod( 'chankhe_post_author_options', 'enable' );

      ?>

        <div class="entry-meta info">
            <?php
                if( !empty( $postdate ) && $postdate == 'enable' ) { chankhe_posted_on(); }
                if( !empty( $postauthor ) && $postauthor == 'enable' ) { chankhe_posted_by(); }
                if( !empty( $postcomment ) && $postcomment == 'enable' ) { chankhe_comments(); }
            ?>
        </div><!-- .entry-meta -->

       <?php
    }
}
add_action( 'chankhe_post_meta', 'chankhe_post_meta' , 10 );


if( ! function_exists( 'chankhe_post_format_media' ) ) :

    /**
     * Posts format declaration function.
     *
     * @since 1.0.0
     */
    function chankhe_post_format_media( $postformat ) {

        global $post;

        if( is_singular( ) ){

          $imagesize = 'post-thumbnail';

        }else{

            $imagesize = '';
        }

        if ($postformat == "gallery") {

            if (function_exists('has_block') && has_block('gallery', $post->post_content)) {

                $post_blocks = parse_blocks($post->post_content);

                $key = array_search('core/gallery', array_column($post_blocks, 'blockName'));
                
                $gallery_attachment_ids = $post_blocks[$key]['attrs']['ids'];

            }else {
                
                $gallery = get_post_gallery( $post->ID, false );

                $gallery_attachment_ids = array();

                if( count($gallery) and isset($gallery['ids'])) {

                    $gallery_attachment_ids = explode ( ",", $gallery['ids'] );

                }
            }

            if ( ! empty( $gallery_attachment_ids ) ){ ?>

                <div class="postgallery-carousel owl-carousel">

                    <?php foreach ( $gallery_attachment_ids as $gallery_attachment_id ) { ?>
                        
                        <img src="<?php echo wp_get_attachment_image_url($gallery_attachment_id, $imagesize); ?>"/>
                        
                    <?php } ?>

                </div>
                
            <?php } else { ?>
                
                <div class="blog-post-thumbnail">
                    <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
                        <?php
                          the_post_thumbnail( $imagesize );
                        ?>
                    </a>
                </div>

            <?php } } else if( $postformat == "video" ){
            
            $get_content  = apply_filters( 'the_content', get_the_content() );
            $get_video    = get_media_embedded_in_content( $get_content, array( 'video', 'object', 'embed', 'iframe' ) );

            if( !empty( $get_video ) ){ ?>

                <div class="video">
                    <?php echo $get_video[0]; // WPCS xss ok. ?>
                </div>

        <?php }else{ ?>

                <div class="blog-post-thumbnail">
                    <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
                        <?php
                          the_post_thumbnail( $imagesize );
                        ?>
                    </a>
                </div>

        <?php  } }else if( $postformat == "audio" ){

            $get_content  = apply_filters( 'the_content', get_the_content() );
            $get_audio    = get_media_embedded_in_content( $get_content, array( 'audio', 'iframe' ) );

            if( !empty( $get_audio ) ){ ?>

                <div class="audio">
                    <?php echo $get_audio[0]; // WPCS xss ok. ?>
                </div>

        <?php }else{  ?>

                <div class="blog-post-thumbnail">
                    <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
                        <?php
                          the_post_thumbnail( $imagesize );
                        ?>
                    </a>
                </div>

        <?php } }else if( $postformat == "quote" ) { ?>

                <div class="post-format-media-quote">
                    <blockquote>
                        <?php the_content(); ?>
                    </blockquote>
                </div>

        <?php }else{ ?>

                <div class="blog-post-thumbnail">
                    <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
                        <?php
                          the_post_thumbnail( $imagesize );
                        ?>
                    </a>
                </div>

        <?php }

    }

endif;


if ( ! function_exists( 'chankhe_footer_copyright' ) ){

    /**
     * Footer Copyright Information
     *
     * @since 1.0.0
     */
    function chankhe_footer_copyright() {

        echo esc_html( apply_filters( 'chankhe_copyright_text', $content = esc_html__('Copyright  &copy; ','chankhe') . date( 'Y' ) . ' ' . get_bloginfo( 'name' ) .' - ' ) );

         printf( ' WordPress Theme : by %1$s', '<a href=" ' . esc_url('https://sparklewpthemes.com/') . ' " rel="designer" target="_blank">'.esc_html__('Sparkle Themes','chankhe').'</a>' );
    }
}
add_action( 'chankhe_copyright', 'chankhe_footer_copyright', 5 );



/**
 * Breadcrumbs Section.
*/
if (! function_exists( 'chankhe_breadcrumbs' ) ):

    function chankhe_breadcrumbs(){ 
        $layout = get_theme_mod('chankhe_header_layout', 'layout-1');
        ?>

        <section class="breadcrumb">
            <?php if($layout == 'layout-1') chankhe_breadcrumbs_content(); ?>
        </section>
        <?php
    }
endif;
add_action('chankhe_breadcrumbs', 'chankhe_breadcrumbs', 100);

add_action('chankhe_breadcrumbs_content', 'chankhe_breadcrumbs_content', 100);
if( !function_exists('chankhe_breadcrumbs_content') ){
    function chankhe_breadcrumbs_content(){
        ?>
        <div class="container">
                <div class="row breadcrumb inner-breadcrumb">
                    <div class="col-xl-12 col-sm-12 col-xs-12">
                        <div class="breadcrumb_wrapper">
                            <?php
                                if (is_single() || is_page()) {

                                    the_title('<h2 class="entry-title">', '</h2>');

                                } elseif (is_archive()) {

                                    the_archive_title('<h2 class="page-title">', '</h2>');
                                    the_archive_description('<div class="taxonomy-description">', '</div>');

                                } elseif (is_search()) { ?>

                                    <h2 class="page-title">
                                        <?php printf(esc_html__('Search Results for:', 'chankhe'), '%s', '<span>' . get_search_query() . '</span>'); ?>
                                    </h2>

                                <?php } elseif (is_404()) {

                                    echo '<h2 class="entry-title">' . esc_html('404 Error', 'chankhe') . '</h2>';

                                } elseif (is_home()) {

                                $page_for_posts_id = get_option('page_for_posts');
                                $page_title = get_the_title($page_for_posts_id);

                            ?>
                                    <h2 class="entry-title"><?php echo esc_html($page_title); ?></h2>

                            <?php }else{ ?>

                                    <h2 class="entry-title"><?php echo esc_html($page_title); ?></h2>

                            <?php }     
                                $breadcrumbs_enable = get_theme_mod('chankhe_enable_breadcrumbs', 'enable');
                                if ($breadcrumbs_enable == 'enable') { 
                            ?>
                                <nav id="breadcrumb" class="cp-breadcrumb">
                                    <?php
                                        breadcrumb_trail(array(
                                            'container' => 'div',
                                            'show_browse' => false,
                                        ));
                                    ?>
                                </nav>
                            <?php } ?>
                        </div>
                    </div>
                </div>
            </div>
            <?php
    }
}


/**
 * Main Slider Function Area
*/
if (! function_exists( 'chankhe_banner_slider' ) ):

    function chankhe_banner_slider(){
        $slider_type = get_theme_mod('chankhe_slider_type', 'default');
        $video_data = '';
        if($slider_type == 'video'):
            $bg_video = get_theme_mod('chankhe_slider_video_url');

            if( $bg_video ):
                $video_data = 'data-property="{videoURL:\'' . $bg_video . '\', mobileFallbackImage:\'https://img.youtube.com/vi/' . $bg_video . '/maxresdefault.jpg\'}"';
            endif;
        endif;

        ?>

        <div id="banner-slider" class="banner-slider features-slider <?php if($slider_type == 'video') echo 'chankhe-video-bg'; ?>"  <?php echo $video_data; ?>>
            <?php 
               
                $bg_image = false;
                if($slider_type == 'default'):
                    $bg_image = get_theme_mod('chankhe_banner_background_image');
                    $repeat = get_theme_mod('chankhe_banner_background_image_repeat','no-repeat');
                    $position = get_theme_mod('chankhe_banner_background_image_position','center center');
                    $attachment = get_theme_mod('chankhe_banner_background_image_attach');
                endif; 
            
                $title  = get_theme_mod('chankhe_banner_title');
                $description  = get_theme_mod('chankhe_banner_description');
                $btn_text  = get_theme_mod('chankhe_banner_btn_text');
                $btn_url  = get_theme_mod('chankhe_banner_btn_url');
               
            ?>

            <div class="slider-item <?php if(!$bg_image): echo "gradient-bg"; endif; ?>" <?php if($bg_image): ?>style="background-image: url(<?php echo esc_url($bg_image); ?>); 
                                                                    background-attachment: <?php echo esc_attr($attachment); ?>;
                                                                    bacground-position: <?php echo esc_attr($position); ?>;
                                                                    background-repeat: <?php echo esc_attr($repeat); ?>" <?php endif; ?>>
                <div class="banner-table">
                    <div class="banner-table-cell">
                        <div class="container">
                            <div class="row">
                                <div class="col-lg-10 mx-auto">
                                    <?php if($title || $description || $btn_text ): ?>
                                    <div class="slider-content">
                                        <?php if($title): ?>
                                        <h2 class="slider-title">
                                            <?php echo esc_html( $title ) ?>
                                        </h2>
                                        <?php endif; ?>

                                        <?php if($description): ?>
                                            <p><?php echo esc_html( $description ); ?></p>
                                        <?php endif; ?>

                                        <?php if( !empty( $btn_url ) ){ ?>
                                            <div class="scroll">
                                                <a href="<?php echo esc_html( $btn_url ); ?>" class="btn__arrow js-smooth-scroll-link">
                                                    <span class="btn__arrow--block"></span>
                                                    <i class="btn__arrow--ic">
                                                        <svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 26.457 24.929" enable-background="new 0 0 26.457 24.929" xml:space="preserve">
                                                            <path d="M12.521,24.223l0.707,0.707l0.707-0.707c0,0,0,0,0.001-0.001l12.228-12.228c0.391-0.391,0.391-1.023,0-1.414
                                                            s-1.023-0.391-1.414,0L14.228,21.101V1c0-0.552-0.448-1-1-1s-1,0.448-1,1v20.101L1.707,10.58c-0.391-0.391-1.023-0.391-1.414,0
                                                            C0.098,10.775,0,11.031,0,11.287c0,0.256,0.098,0.512,0.293,0.707L12.521,24.223C12.521,24.222,12.521,24.222,12.521,24.223z"></path>
                                                        </svg>
                                                    </i>
                                                    <!-- <i class="fas fa-long-arrow-alt-right"></i> -->
                                                </a>
                                            </div>
                                        <?php } ?>

                                    </div> <!-- slider content end-->
                                    <?php endif; ?>
                                </div> <!-- col end-->
                            </div> <!-- row end-->
                        </div><!-- container end -->
                    </div><!-- banner table cell end -->
                </div><!-- banner table end -->
            </div>
        </div><!-- Slider section end -->

    <?php }
endif;
add_action('chankhe_action_banner_slider', 'chankhe_banner_slider', 25);


/**
 * Our Service Featues Section.
*/
if (! function_exists( 'chankhe_promo_service' ) ):

    function chankhe_promo_service(){

        $features_options = get_theme_mod('chankhe_features_service_section','enable');
        
        if( !empty( $features_options ) && $features_options == 'enable' ){ ?>

        <section id="chankhefeature" class="chankhefeature">
            <div class="container">
                <div class="row">
                    <?php
                        $promo_service = get_theme_mod('chankhe_promo_service');
                        $count = 1;
                        if (!empty($promo_service)):

                        $pages = json_decode($promo_service);

                        foreach ($pages as $page):

                        $page_id = $page->promoservice_page;

                        if (!empty($page_id)):

                            $service_query = new WP_Query('page_id=' . $page_id);

                            if ( $service_query->have_posts() ): while ( $service_query->have_posts() ): $service_query->the_post();
                    ?>
                        <div class="col-lg-4 col-md-6 col-sm-6 col-xs-12 feature-list">
                            <div class="bottom-content">
                                <div class="icon-box">
                                    <a href="<?php the_permalink(); ?>"><i class="<?php echo esc_attr( $page->promoservice_icon ); ?>"></i></a>
                                </div>
                                    <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
                                    <?php the_excerpt(); ?>
                            </div>
                        </div>
                    <?php  $count++; endwhile;  endif; endif; endforeach; endif; ?>
                </div>
            </div>
        </section>

        <?php } }
endif;
add_action('chankhe_action_promo_service', 'chankhe_promo_service', 30);


/**
 * About Us Section.
*/
if (! function_exists( 'chankhe_about' ) ):

    function chankhe_about(){ 

        $aboutus_options = get_theme_mod('chankhe_aboutus_service_section','enable');
        
        if( !empty( $aboutus_options ) && $aboutus_options == 'enable' ){ ?>

        <section id="about_us_front" class="about_us_front">
            <div class="container">
                <div class="row">
                    <?php
                        $aboutus = get_theme_mod('chankhe_aboutus');

                        if (!empty( $aboutus ) ):

                        $aboutus_args = array(
                            'posts_per_page' => 1,
                            'post_type' => 'page',
                            'page_id' => $aboutus,
                            'post_status' => 'publish',
                        );

                        $aboutus_query = new WP_Query($aboutus_args);

                        if ( $aboutus_query->have_posts() ) : while ( $aboutus_query->have_posts() ) : $aboutus_query->the_post();
                    
                        $about_image = get_theme_mod('chankhe_aboutus_image');

                        $top_title = get_theme_mod('chankhe_aboutus_top_title');

                        $about_col = '';
                        if( !empty( $about_image ) ){
                            $about_col = 6;
                        }else{
                            $about_col = 12;
                        }
                    ?>
                        <div class="col-lg-<?php echo intval( $about_col ); ?> col-md-<?php echo intval( $about_col ); ?> col-sm-12">
                            <?php if( !empty( $top_title ) ){ ?><h4 class="about_top_title"><?php echo esc_html( $top_title ); ?></h4><?php } ?>
                            <h2 class="about_title"><?php the_title(); ?></h2>
                            <div><?php the_content(); ?></div>
                        </div>

                        <?php if (!empty($about_image)): ?>
                            <div class="col-lg-6 col-md-6 col-sm-12">
                                <div class="aboutimgwrap"><img src="<?php echo esc_url( wp_get_attachment_url( $about_image ) ); ?>"/></div>
                            </div>
                        <?php endif; ?>

                    <?php endwhile; endif; endif; ?>
                </div>
            </div>
        </section>

    <?php } }
endif;
add_action('chankhe_action_about', 'chankhe_about', 35);


/**
 * Video Call To Action Section.
*/
if (! function_exists( 'chankhe_video_calltoaction' ) ):

    function chankhe_video_calltoaction(){

        if( function_exists( 'pll_register_string' ) ){

            $video_cta_title = pll__( get_theme_mod('chankhe_video_calltoaction_title') );
            $video_cta_sub_title = pll__( get_theme_mod('chankhe_video_calltoaction_subtitle') );
        
        }else{

            $video_cta_title     = get_theme_mod( 'chankhe_video_calltoaction_title' );
            $video_cta_sub_title = get_theme_mod( 'chankhe_video_calltoaction_subtitle' );

        }

        $yourtube_video_url  = get_theme_mod('chankhe_video_button_url');
        $video_cta_options = get_theme_mod('chankhe_video_cta_service_section','enable');

        if( !empty( $video_cta_options ) && $video_cta_options == 'enable' ){ ?>

            <div id="calltoactionvideo_promo_wrapper" class="calltoaction_promo_wrapper video_calltoaction">
                <div class="container">
                    <div class="row">
                        <?php
                            $top_title = get_theme_mod('chankhe_video_calltoaction_top_title');
                            $cta_page  = get_theme_mod('chankhe_cta_page');

                            $button_text = get_theme_mod('chankhe_video_cta_button_text','Call For Booking');
                            $button_url = get_theme_mod('chankhe_video_cta_button_url');

                            if (!empty( $cta_page ) ):

                            $cta_page_args = array(
                                'posts_per_page' => 1,
                                'post_type' => 'page',
                                'page_id' => $cta_page,
                                'post_status' => 'publish',
                            );

                            $cta_page_query = new WP_Query($cta_page_args);

                            if ( $cta_page_query->have_posts() ) : while ( $cta_page_query->have_posts() ) : $cta_page_query->the_post();
                        
                            if( !empty( $cta_page ) ){
                                $cta_page = 6;
                            }else{
                                $cta_page = 12;
                            }
                        ?>
                            <div class="col-lg-<?php echo intval( $cta_page ); ?> col-md-<?php echo intval( $cta_page ); ?> col-sm-12">
                                <div class="video_cta_page_wrap">
                                    <?php if( !empty( $top_title ) ){ ?><h4 class="about_top_title primary-color"><?php echo esc_html( $top_title ); ?></h4><?php } ?>
                                    <h2 class="about_title default-color"><?php the_title(); ?></h2>
                                    <div class="default-color"><?php echo esc_html(wp_trim_words( get_the_content(),30)); ?></div>
                                    <a href="<?php the_permalink(); ?>" class="btn btn-primary btncta">
                                        <?php echo esc_html('See Detail','Read More'); ?>
                                        <i class="fas fa-long-arrow-alt-right"></i>
                                    </a>
                                </div>
                            </div>

                            <div class="col-lg-6 col-md-6 col-sm-12">
                                <div class="video_cta_wrap">
                                    <div class="video_calltoaction_wrap">
                                        <a href="<?php echo esc_url( $yourtube_video_url ); ?>" target="_blank" class="popup-youtube  box-shadow-ripples"><i class="fas fa-play "></i></a>
                                    </div>
                                    <div class="cta_title_wrap">
                                        <h4 class="about_top_title"><?php echo esc_html( $video_cta_title ); ?></h4>
                                        <h2 class="about_title"><?php echo esc_html( $video_cta_sub_title ); ?></h2>
                                        <?php if( !empty( $button_text ) ){ ?>
                                            <a href="<?php echo esc_html( $button_url ); ?>" class="btn btn-primary btncta">
                                                <?php echo esc_html( $button_text ); ?>
                                                <i class="fas fa-long-arrow-alt-right"></i>
                                            </a>
                                        <?php } ?>
                                    </div>
                                </div>
                            </div>
                        <?php endwhile; endif; endif; ?>
                    </div>
                </div>
            </div>

    <?php } }
endif;
add_action('chankhe_action_video_calltoaction', 'chankhe_video_calltoaction', 40);


/**
 * Our Main Service Section.
*/
if (! function_exists( 'chankhe_service' ) ):
    function chankhe_service(){

        $title          = get_theme_mod('chankhe_service_title');
        $sub_title      = get_theme_mod('chankhe_service_sub_title');
        $service_page   = get_theme_mod('chankhe_service');
        
        $services_options = get_theme_mod('chankhe_service_service_section','enable');
        
        if( !empty( $services_options ) && $services_options == 'enable' ){ ?>

        <section id="chankheservices" class="chankheservices">
            <div class="container">
                
                <?php chankhe_section_title( $title, $sub_title ); ?>

                <div class="row">
                    <?php
                        if (!empty($service_page)):

                        $pages = json_decode($service_page);

                        foreach ($pages as $page):

                            $page_id = $page->service_page;

                            if (!empty($page_id)):

                            $service_query = new WP_Query('page_id=' . $page_id);

                            if ( $service_query->have_posts() ): while ( $service_query->have_posts() ): $service_query->the_post();

                    ?>
                        <div class="col-lg-4 col-md-6 col-sm-6 col-xs-12 feature-list">
                            <div class="box">
                                <figure>
                                    <a href="<?php the_permalink(); ?>">
                                        <?php the_post_thumbnail('chankhe-medium'); ?>
                                    </a>
                                </figure>
                                <div class="bottom-content">
                                    <h3 class="default-color"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                                    <div class="default-color"><?php the_excerpt(); ?></div>
                                    <a href="<?php the_permalink(); ?>" class="btn btn-primary default-color">
                                        <?php echo esc_html(get_theme_mod('chankhe_service_button','Read More')); ?>
                                        <i class="fas fa-angle-double-right"></i>
                                    </a>
                                </div>
                            </div>
                        </div>
                    <?php endwhile; endif; endif; endforeach; endif; ?>
                </div>
            </div>
        </section>

    <?php } }
endif;
add_action('chankhe_action_service', 'chankhe_service', 45);

/**
 *  Success Product Counter Section.
*/
if (! function_exists( 'chankhe_counter' ) ):

    function chankhe_counter(){
        
        $title = get_theme_mod('chankhe_counter_title');
        $sub_title = get_theme_mod('chankhe_counter_sub_title');

        $counter_options = get_theme_mod('chankhe_counter_section','enable');
        if( !empty( $counter_options ) && $counter_options == 'enable' ){ ?>

        <section id="chankhecounter_wrap" class="chankhecounter_wrap">
            <div class="container">

                <?php chankhe_section_title( $title, $sub_title ); ?>

                <div class="row chankheteam-counter-wrap">
                    <?php
                        $counter_page = get_theme_mod('chankhe_counter');

                        if (!empty($counter_page)):

                        $counters = json_decode($counter_page);
                        $i = 1;
                        foreach ( $counters as $counter ):
                    ?>
                        <div class="col-lg-3 col-md-6 col-sm-6">
                            <div class="chankhecounter">
                                <div class="chankhecounter-count odometer odometer<?php echo esc_attr($i); ?>" data-count="<?php echo absint($counter->counter_number); ?>">
                                    99
                                </div>
                                <h6 class="chankhecounter-title">
                                    <?php echo esc_html( $counter->counter_title ); ?>
                                </h6>
                            </div>
                        </div>
                    <?php  $i++; endforeach; endif; ?>
                </div>
            </div>
        </section>

    <?php } }
endif;
add_action('chankhe_action_counter', 'chankhe_counter', 60);


/**
 *  Blog Section.
*/
if (! function_exists( 'chankhe_blog' ) ):
    function chankhe_blog(){

        $title = get_theme_mod('chankhe_blog_title');
        $sub_title = get_theme_mod('chankhe_blog_sub_title');

        if( function_exists( 'pll_register_string' ) ){ 

            $blogreadmore_btn = pll__( get_theme_mod( 'chankhe_blogtemplate_btn', 'Read More' ) );

        }else{ 

            $blogreadmore_btn = get_theme_mod( 'chankhe_blogtemplate_btn', 'Read More' );

        }

        $blog_options = get_theme_mod('chankhe_home_blog_section','enable');

        if( !empty( $blog_options ) && $blog_options == 'enable' ){ ?>

        <section id="chankheblog" class="chankheblog-list-area">
            <div class="container">

                <?php chankhe_section_title( $title, $sub_title ); ?>

                <div class="row">
                    <?php
                        $blog = get_theme_mod('chankhe_blog');
                        $cat_id = explode(',', $blog);
                        $blog_posts = get_theme_mod('chankhe_posts_num', 'three');

                        if ($blog_posts == 'three') {

                            $post_num = 3;

                        } else {

                            $post_num = 6;

                        }

                        $args = array(
                            'posts_per_page' => $post_num,
                            'post_type' => 'post',
                            'tax_query' => array(

                                array(
                                    'taxonomy' => 'category',
                                    'field' => 'term_id',
                                    'terms' => $cat_id
                                ),
                            ),
                        );

                        $blog_query = new WP_Query ($args);

                        if ( $blog_query->have_posts() ): while ( $blog_query->have_posts() ) : $blog_query->the_post();
                    ?>
                        <div class="col-lg-4 col-md-6 col-sm-6 col-xs-12 articlesListing blog-grid">
                            <article id="post-<?php the_ID(); ?>" <?php post_class('article default-color'); ?>>
                                <div class="blog-post-thumbnail">
                                    <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
                                        <?php the_post_thumbnail(); ?>
                                    </a>
                                </div>
                                <div class="box">
                                    <?php 

                                        the_title( '<h3 class="title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h3>' ); 

                                        if ( 'post' === get_post_type() ){ do_action( 'chankhe_post_meta', 10 ); } 
                                    ?>
                                    
                                    <div class="entry-content">
                                        <?php the_excerpt(); ?>
                                    </div>

                                    <div class="btns text-center">
                                        <a href="<?php the_permalink(); ?>" class="btn btn-primary">
                                            <span><?php echo esc_html( $blogreadmore_btn ); ?> <i class="fas fa-angle-double-right"></i></span>
                                        </a>
                                    </div>
                                    
                                </div>

                            </article><!-- #post-<?php the_ID(); ?> -->
                        </div>
                    <?php endwhile; endif; ?>
                </div>
            </div>
        </section>

    <?php } }
endif;
add_action('chankhe_action_blog', 'chankhe_blog', 65);


/**
 *  Testimonial Section.
*/
if (! function_exists( 'chankhe_testimonial' ) ):
    function chankhe_testimonial(){

        $title = get_theme_mod('chankhe_testimonial_title');
        $sub_title = get_theme_mod('chankhe_testimonial_sub_title');

        $testimonial_page = get_theme_mod('chankhe_testimonials'); 

        $testimonial_options = get_theme_mod('chankhe_testimonial_options','enable');
        if( !empty( $testimonial_options ) && $testimonial_options == 'enable' ){ ?>

        <section id="chankhetestimonial" class="chankhetestimonial">
            <div class="container">

                <?php chankhe_section_title( $title, $sub_title ); ?>

                <div class="row">
                    <div class="owl-carousel owl-theme testimonial_slider">
                        <?php
                            if (!empty($testimonial_page)):

                            $testimonial_pages = json_decode($testimonial_page);

                            foreach ($testimonial_pages as $testimonial_page):

                            $page_id = $testimonial_page->testimonial_page;

                            if (!empty($page_id)):

                            $testimonial_query = new WP_Query('page_id=' . $page_id);

                            if ( $testimonial_query->have_posts() ): while ($testimonial_query->have_posts()): $testimonial_query->the_post();
                        ?>
                            <div class="testimonialbox default-color">
                                <p><?php echo esc_html( wp_trim_words( get_the_content(), 20, '.' ) );?></p>
                                <div class="testimonialwrap">
                                    <?php the_post_thumbnail('thumbnail'); ?>
                                    <div class="testimonialtitle">
                                        <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
                                        <p><?php echo esc_html( $testimonial_page->designation_title ); ?></p>
                                    </div>
                                </div>
                            </div>

                        <?php endwhile; endif; endif; endforeach; endif; ?>

                    </div>
                </div>
            </div>
        </section>

    <?php } }
endif;
add_action('chankhe_action_testimonial', 'chankhe_testimonial', 70);


/**
 *  Our Team Member Section
*/
if (! function_exists( 'chankhe_team' ) ):
    function chankhe_team(){

        $title = get_theme_mod('chankhe_team_title');
        $sub_title = get_theme_mod('chankhe_team_sub_title');

        $team_page = get_theme_mod('chankhe_team');

        $team_options = get_theme_mod('chankhe_team_options','enable');
        if( !empty( $team_options ) && $team_options == 'enable' ){ ?>

        <section id="chankheteam" class="chankheteam">
            <div class="container">
                
                <?php chankhe_section_title( $title, $sub_title ); ?>

                <div class="row">
                    <?php

                        if (!empty( $team_page ) ):

                        $team_pages = json_decode($team_page);

                        foreach ($team_pages as $team_page):
                        
                        $page_id = $team_page->team_page;

                            if (!empty( $page_id )):

                            $team_query = new WP_Query('page_id=' . $page_id);

                            if ($team_query->have_posts()): while ($team_query->have_posts()): $team_query->the_post();
                    ?>

                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="teamwrap default-color">
                                <figure>
                                    <?php the_post_thumbnail('chankhe-medium'); ?>
                                </figure>

                                <div class="teamdesc">

                                    <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>

                                    <?php the_excerpt(); ?>

                                    <ul class="sp_socialicon">
                                        <?php if (!empty( $team_page->facebook ) ) : ?>
                                            <li>
                                                <a href="<?php echo esc_url( $team_page->facebook ); ?>">
                                                    <i class="fab fa-facebook-f"></i>
                                                </a>
                                            </li>
                                        <?php endif; if (!empty( $team_page->twitter ) ) : ?>
                                            <li>
                                                <a href="<?php echo esc_url($team_page->twitter); ?>">
                                                    <i class="fab fa-twitter"></i>
                                                </a>
                                            </li>
                                        <?php endif; if (!empty( $team_page->linkedin ) ) : ?>
                                            <li>
                                                <a href="<?php echo esc_url($team_page->linkedin); ?>">
                                                    <i class="fab fa-linkedin-in"></i>
                                                </a>
                                            </li>
                                        <?php endif; if (!empty( $team_page->instagram ) ) : ?>
                                            <li>
                                                <a href="<?php echo esc_url($team_page->instagram); ?>">
                                                    <i class="fab fa-instagram"></i>
                                                </a>
                                            </li>
                                        <?php endif; ?>
                                    </ul>

                                </div>
                            </div>
                        </div>

                    <?php endwhile; endif; endif; endforeach; endif; ?>
                </div>
            </div>
        </section>

    <?php } }
endif;
add_action('chankhe_action_team', 'chankhe_team', 75);

if(! function_exists('chankhe_text_alignment_class')){
    function chankhe_text_alignment_class(){
        return array(
            'text-left' => __("Left", 'chankhe'),
            'text-center' => __("Center", 'chankhe'),
            'text-right' => __("Right", 'chankhe'),
        );
    }
}